*************************************************
*************** ILE MERGE FILE ******************
*************************************************

********************************************************
** 1. MERGE FILES
********************************************************	
		
// Wave: baseline, endline (1Y) and endline (2Y)
// Round: 1=11m 2=12m 3=13m 4=23m 5=25m

	// Temp Files
		tempfile temp_ei11 temp_ei12 temp_ei13 temp_ei23 temp_ei25 temp_eh11 temp_eh12 temp_eh23 temp_e11 temp_e12 temp_e23	
	
	// ENDLINE INDIVIDUAL (11 MONTH)
		
		use "$ILEdata/raw/ILE.ind.1123m_clean.dta", clear
	
		keep if wave=="11m"

		* Check Duplicates
			duplicates tag appid, gen (dup)
			drop if appid==.
			assert dup ==0
			drop dup
		
		drop wave
		gen round_i=1
		gen wave_i=1
		
		sort appid
		save "`temp_ei11'", replace
	
	// ENDLINE INDIVIDUAL (12 MONTH)-- ONLY for P101
	
		use "$ILEdata/raw/ILE.ind.12m_clean.dta", clear
		
		* Check Duplicates
			duplicates tag appid, gen (dup)
			assert dup ==0
			drop dup
		
		gen round_i=2
		gen wave_i=1
		
		sort appid
		save "`temp_ei12'", replace
		
	// ENDLINE INDIVIDUAL (13 MONTH)
		
		use "$ILEdata/raw/ILE.ind.1325m_clean.dta", clear

		keep if wave=="13m"
		
		* Check Duplicates
			duplicates tag appid, gen (dup)
			drop if dup == 1 & timestamp01 == "9/5/2014 7:48:31"
			*assert dup ==0
			drop dup
		
		gen round_i=3
		gen wave_i=1
		
		replace c2_helpoutsum="150" if c2_helpoutsum=="$150.00" // 
		replace c2_helpoutsum="200" if c2_helpoutsum=="$200.00"
		replace c2_helpoutsum="25" if c2_helpoutsum=="$25.00"
		destring c2_helpoutsum, replace
	 
		sort appid
		save "`temp_ei13'", replace
	
	// ENDLINE INDIVIDUAL (23 MONTH)
		
		use "$ILEdata/raw/ILE.ind.1123m_clean.dta", clear
		
		keep if wave=="23m"
	
		* Check Duplicates
			duplicates tag appid, gen (dup)
			assert dup ==0
			drop dup
	
		gen round_i=4
		gen wave_i=2
		
		sort appid
		save "`temp_ei23'", replace
	
	// ENDLINE INDIVIDUAL (25 MONTH)
		
		use "$ILEdata/raw/ILE.ind.1325m_clean.dta", clear
		
		keep if wave=="25m"
		
		* Check Duplicates
			duplicates tag appid, gen (dup)
			assert dup ==0
			drop dup
		
		drop wave
		gen round_i=5
		gen wave_i=2
		destring c2_helpoutsum, replace

		sort appid
		save "`temp_ei25'", replace
		
	// ENDLINE HOUSEHOLD
		
		// 11 month HH survey
		
			use "$ILEdata/raw/ILE.hh_clean.dta", clear
			
			keep if wave=="11m"
			
			* Check Duplicates
				duplicates tag appid, gen (dup)
				assert dup ==0
				drop dup
			
			drop wave
			gen round_h=1
			gen wave_h=1
			
			sort appid
			save "`temp_eh11'", replace
			
			use "$ILEdata/raw/ILE.hh_clean.dta", clear
		
		// 12 month HH survey
		
			keep if wave=="12m"
			
			* Check Duplicates
				duplicates tag appid, gen (dup)
				assert dup ==0
				drop dup
			
			drop wave
			gen round_h=2
			gen wave_h=1
			
			sort appid
			save "`temp_eh12'", replace
			
			use "$ILEdata/raw/ILE.hh_clean.dta", clear
		
		// 23 month HH survey
		
			keep if wave=="23m"
		
			* Check Duplicates
				duplicates tag appid, gen (dup)
				assert dup ==0
				drop dup
			
			drop wave
			gen round_h=4
			gen wave_h=2
			
			sort appid
			save "`temp_eh23'", replace

	// COMBINING ENDLINE DATABASES
		
		// Merging individual and HH surveys (11m, 12m and 23m)

		foreach x in 11 12 23 {
			use "`temp_ei`x''", clear
			merge appid using "`temp_eh`x''", _merge(_merge_e`x')
			tostring translator, replace
			save "`temp_e`x''", replace
		}
		clear
				
	// Appending all endline databases
		
		foreach x in e12 ei13 ei25 {
			use "`temp_`x''", clear
			tostring c2_helpoutsum, replace
			save "`temp_`x''", replace
			}
		
		use "`temp_e11'", clear
		append using "`temp_e12'" "`temp_ei13'" "`temp_e23'" "`temp_ei25'"
		so appid
		destring c2_helpoutsum, replace
		saveold "$ILEdata/ILE.el_clean.dta", replace

		
********************************************************
** 7. VARIABLE CONSTRUCTION
********************************************************
		
	// CONSTRUCT baseline vars here (and suffix _b) 
	
		do ILE.bl_construct.do

		* Suffix _b
			unab allvar: _all
			foreach var of local allvar {
				ren `var' `var'_b
			}
			
		// ren id variables
			ren appid_b appid
			ren projid_b projid
			ren facid_b facid
	
		saveold "$ILEdata/ILE.bl_construct.dta", replace 
	
	// CONSTRUCT endline vars here (and suffix _e)	

		do ILE.el_construct.do

	// Suffix _e
			unab allvar: _all
			foreach var of local allvar {
				ren `var' `var'_e
			}
			
			gen e1 = 1 if round_i == 0 | round_i == 1 | round_i == 2 | round_h == 1 | round_h == 2
			gen e2 = 1 if round_i == 3 
			gen e3 = 1 if round_i == 4 | round_h == 4
			gen e4 = 1 if round_i == 5
		
	//  ren id variables
			ren appid_e appid
			ren projid_e projid
			ren facid_e facid
			ren round_i_e round_i
			ren wave_i_e wave_i
			ren round_h_e round_h
			ren wave_h_e wave_h
		
			sort appid	
			saveold "$ILEdata/ILE.el_construct.dta", replace 

********************************************************
** 8. MERGING BASELINE AND ENDLINE / OTHER DATA
********************************************************
	
	use "$ILEdata/ILE.bl_construct.dta", clear
	
		* Check Duplicates
			duplicates tag appid, gen (dup)
			assert dup ==0
			drop dup
	
		* Generate 11 and 13 month rows of data
			expand 3 if projid == 101
			expand 4 if projid >101
			bys appid: gen count = _n
			gen e1 = 1 if count == 1 & projid >101
			gen e2 = 1 if count == 2 & projid >101
			gen e3 = 1 if count == 3 & projid >101
			gen e4 = 1 if count == 4 & projid >101
			replace e1 = 1 if count == 1 & projid ==101
			replace e3 = 1 if count == 2 & projid ==101
			replace e4 = 1 if count == 3 & projid ==101
			drop count 
			
			sort appid
			saveold"$ILEdata/ILE.bl_construct.dta", replace 
		
	// Merge in endline construction database
	
		merge m:m appid e1 e2 e3 e4 using "$ILEdata/ILE.el_construct.dta"
		ren _merge _merge_e

	// generate universal round and wave variables	
		gen round=round_i
			replace round=round_h if round_i==.
			replace round=1 if e1 == 1 & round == . & projid >101
			replace round=2 if e1 == 1 & round == . & projid == 101
			replace round=3 if e2 == 1 & round == .
			replace round=4 if e3 == 1 & round == .
			replace round=5 if e4 == 1 & round == .
		gen wave=cond(round!=.,cond(round<=3,1,2),.)
			
	// 	Labels
		
		la define projid 101 "Burayu 1" 102 "Burayu 2" 103 "Jittu" 104 "Redfox" 105 "Maa" 106 "Anbesa" 107 "Maa2" 108 "Maa3"
		la val projid projid

		label define round 0 "bl only" 1 "11 month" 2 "12 month" 3 "13 month" 4 "23 month" 5 "25 month"
		label val round round_i round_h round
		label define wave 1 "1 yr after baseline" 2 "2 yrs after baseline"
		label val wave wave_i wave_h wave
		
		label var round "Round of survey for cohort"
		label var round_i "Round of survey for cohort: individual survey"
		label var round_h "Round of survey for cohort: household survey"
			
		label var wave "Wave of survey: 1 year or 2 years"
		label var wave_i "Wave of survey: individual survey"
		label var wave_h "Wave of survey: household survey"
			
	// Generate unique id after new double endline measures (move this to master file)

		bys appid: gen count =_n
		gen round_b = 1 if count == 1
		lab var round_b "Unique ID"

	// unique surveyid
		
		egen surveyid=concat(appid round), format(%12.0g)
	
		destring surveyid, replace
		so surveyid round
	
	*****************************************
	saveold "$ILEdata/ILEanalysis.dta", replace 
	*****************************************

	// Merge cash grant allocation data
		
		insheet using "$ILEdata/raw/Cash Grant Allocation Data.csv", comma names clear
			drop projid
			/* There is 1 set of duplicates */
			duplicates drop
			rename rent cga_biz_rent
			rename input cga_biz_input
			rename salary cga_biz_salary
			rename operationalcosts cga_biz_opcosts
			rename savingsathome cga_save_home
			rename savingsatbank cga_save_bank
			rename food cga_cons_food
			rename clothes cga_cons_cloth
			rename medical cga_cons_med
			rename other cga_cons_other
			rename transfertofamilyandfriends cga_trans
			rename creditfrombank cga_add_bankcred
			rename creditfromfamily cga_add_famcred
			rename creditfromfriends cga_add_friendcred
			rename personalsavings cga_add_perssav

			
			foreach v of varlist cga_* {
				egen temp = mean(`v'), by(appid)
				replace `v' = temp
				drop temp
			}
			
			egen tot = rowtotal(cga_biz_rent-cga_trans), m
			
			egen cga_biz = rowtotal(cga_biz*), m
				la var cga_biz "Business expenses"
			egen cga_save = rowtotal(cga_save*), m
				la var cga_save "Savings"
			egen cga_cons = rowtotal(cga_cons*), m
				la var cga_cons "Consumption"
			egen cga_add = rowtotal(cga_add*), m
				la var cga_add "Additional contributions for business investment"

			egen cga_nonbiz = rowtotal(cga_save cga_cons cga_trans), m
				la var cga_nonbiz "Non-business expenses"
			
			gen cga_addinv = cga_add > 0 if !missing(cga_add)
				la var cga_addinv "Indicator: Added own funds to CG for business investment"
			gen cga_addinv_amt = cga_add - cga_nonbiz
				replace cga_addinv_amt = 0 if cga_addinv_amt < 0
				replace cga_addinv_amt = cga_addinv_amt * 100 if cga_addinv_amt < 100
				la var cga_addinv_amt "Additional capital contributed to business (net of grant spending on non-business expenses)"
			
			foreach v of varlist cga_biz_rent-cga_trans cga_biz cga_save cga_cons cga_nonbiz {
				qui replace `v' = `v' / tot
				qui la var `v' "Share of grant spent on: `:var label `v''"
			}
			foreach v of varlist cga_add_bankcred - cga_add_perssav {
				qui la var `v' "Added business investment from: `:var label `v''"
			}
			drop tot
			

		saveold "$ILEdata/ILE_CGA.dta", replace 

		use "$ILEdata/ILEanalysis.dta", clear
			merge m:1 appid using "$ILEdata/ILE_CGA.dta", nogen
			
		***********************************
		saveold "$ILEdata/ILEanalysis.dta", replace 
		*****************************************
	
********************************************************
** 9. FIXING VARIABLE ORDER
********************************************************	

	
	
********************************************************
** 10. Found variable to select exactly what we want
********************************************************

// Generate dummies
	
		// dummy for survey round found 
			gen found_ei1 = (round_i == 1 | round_i == 2)
				lab var found_ei1 "Found at 11 month"
	
			gen found_ei2 = (round_i == 3)
				lab var found_ei2 "Found at 13 month"
			
			gen found_hh = (round_h ==1 | round_h == 2)
			lab var found_hh "Found for Household Survey"
		
			gen found_ei3 = (round_i == 4)
				lab var found_ei3 "Found at 23 month"
			
			gen found_ei4 = (round_i == 5)
				lab var found_ei4 "Found at 25 month"
		
	
	
			// 11m & 12m
			gen sought_e1 = 1 if round_b == 1 
			replace sought_e1 =0 if sought_e1 ==. 
			
			// 13m data
			gen sought_e2 = 1 if e2 == 1 & projid < 108
			replace sought_e2 = 0 if projid == 101 
			replace sought_e2 = 0 if sought_e2 ==.

			// hh 
			gen sought_hh = 1 if round_b == 1 
			replace sought_hh = 0 if sought_hh == . 

			gen found = (round_i == 1 | round_i == 2 | round_i == 3 | round_i == 4 | round_i == 5)
			gen unfound_e = found == 0 if !missing(found)
 
********************************************************
** 11. Treatment Definitions
********************************************************

/* Use endline surveys to determent where people worked */
		/* Fix Factory Names */
		foreach f in reg1orgname_e reg2orgname_e reg3orgname_e reg4orgname_e reg5orgname_e reg6orgname_e {
			replace `f' = trim(itrim(lower(`f')))
			/* Burayu Real Water */
				tab `f' if strpos(`f',"real")!= 0 & strpos(`f',"water")!= 0
				replace `f'="burayu real water" if strpos(`f',"real")!= 0 & strpos(`f',"water")!= 0
				tab `f' if strpos(`f',"water")!= 0
				tab `f' if strpos(`f',"real")!= 0
				tab `f' if strpos(`f',"burayu")!= 0 & strpos(`f',"water")!= 0
				replace `f'="burayu real water" if strpos(`f',"burayu")!= 0 & strpos(`f',"water")!= 0
				tab `f' if `f' == "real wter factory"
				replace `f'="burayu real water" if `f' == "real wter factory"
				replace `f'="burayu real water - liberal" if `f' == "private" & (projid == 101 | projid == 102)
				
			/* Redfox */
				tab `f' if strpos(`f',"red")!= 0 & strpos(`f',"fox")!= 0
				replace `f'="red fox farms" if strpos(`f',"red")!= 0 & strpos(`f',"fox")!= 0
				replace `f'="red fox farms" if `f' == "tedfox flower farm" | `f' == "read fox" | `f' == "refox flowers farm" 
				replace `f'="red fox farms - liberal" if `f' == "diffrent agricultural farms" 
			/* Jittu */
				tab `f' if strpos(`f',"jittu")!= 0
				replace `f'="jittu horticulture" if strpos(`f',"jittu")!= 0
				tab `f' if strpos(`f',"jitu")!= 0
				replace `f'="jittu horticulture" if strpos(`f',"jitu")!= 0
				tab `f' if strpos(`f',"jtu")!= 0
				replace `f'="jittu horticulture" if strpos(`f',"jtu")!= 0
				tab `f' if strpos(`f',"jetu")!= 0
				replace `f'="jittu horticulture" if strpos(`f',"jetu")!= 0 | `f' == "gittu agriculture"	
			/* Anbesa Shoe */
				tab `f' if strpos(`f',"anbesa")!= 0 & strpos(`f',"shoe")!= 0
				replace `f'="anbesa shoe" if strpos(`f',"anbesa")!= 0 & strpos(`f',"shoe")!= 0
				tab `f' if strpos(`f',"ambesa")!= 0 & strpos(`f',"shoe")!= 0
				replace `f'="anbesa shoe" if strpos(`f',"ambesa")!= 0 & strpos(`f',"shoe")!= 0
				tab `f' if strpos(`f',"anbessa")!= 0 & strpos(`f',"shoe")!= 0
				replace `f'="anbesa shoe" if strpos(`f',"anbessa")!= 0 & strpos(`f',"shoe")!= 0
				replace `f'="anbesa shoe" if `f' == "anibesa shoe factory" | `f' == "anbasa shoe" | `f' == "ambedsa shoe" | ///
					`f' == "ambessa shoe" | `f' == "anbasa shoe factory" | `f' == "anbes shoe factory" | `f' == "anbsa shoe" | `f' == "ambasa shoe"
				replace `f'="anbesa shoe - liberal" if `f' == "private" & (projid == 106)
			/* Maa Garment */
				replace `f' = subinstr(`f',"garement","garment",.)
				tab `f' if strpos(`f',"maa")!= 0
				replace `f' = "maa garment" if strpos(`f',"maa")!= 0
				tab `f' if strpos(`f',"ma g")!= 0
				replace `f' = "maa garment" if strpos(`f',"ma ")!= 0
				tab `f' if strpos(`f',"ma'garment")!= 0
				replace `f' = "maa garment" if strpos(`f',"ma'garment")!= 0			
				tab `f' if strpos(`f',"magarment")!= 0
				replace `f' = "maa garment" if strpos(`f',"magarment")!= 0
				tab `f' if `f' == "may garment"
				replace `f' = "maa garment" if `f' == "may garment" | `f' == "m a garment" | `f' == "m.a. garment" | `f' == "m garment"
			replace `f' = proper(`f')
		}
			/* Clean up sectors   */
			foreach f in reg1sect_e reg2sect_e reg3sect_e reg4sect_e reg5sect_e reg6sect_e{
				replace `f' = trim(itrim(lower(`f')))
				/* Agriculture */
					tab `f' if strpos(`f',"agri")!= 0 
					replace `f'="agriculture" if strpos(`f',"agri")!= 0
					tab `f' if strpos(`f',"agro")!= 0 
					replace `f'="agriculture" if strpos(`f',"agro")!= 0
					tab `f' if strpos(`f',"horticul")!= 0
					replace `f'="agriculture" if strpos(`f',"horticul")!= 0
					tab `f' if strpos(`f',"veg")!= 0
					replace `f'="agriculture" if strpos(`f',"veg")!= 0	
					tab `f' if strpos(`f',"farm")!= 0
					replace `f'="agriculture" if strpos(`f',"farm")!= 0	
					tab `f' if strpos(`f',"flower")!= 0
					replace `f'="agriculture" if strpos(`f',"flower")!= 0	
					replace `f'="agriculture" if `f'=="agrculture" | `f' == "agircultuer research center" | `f' == "agicultural" | ///
						`f' == "holticultute" | `f' == "floury foctoury" | `f' == "gegetable" | `f' == "green house" | ///
						`f' == "hybriding plants" | `f' == "maize firm" | `f' == "nursery of seedling" | `f' == "seed prodction" | ///
						`f' == "sorgem harvest" | `f' == "sugar cane" | `f' == "hortivulture" | `f' == "sugarcane plant growing" | ///
						`f' == "seed or plant breeding" | `f' == "seedling(nursery)" | `f' == "seed breeding(holticulture)" | ///
						`f' == "seed breeding system" | `f' == "cultication plants" | `f' == "agrucutural" | `f' == "seed breeding" | ///
						`f' == "laboror"
				/* Factory */
					tab `f' if strpos(`f',"factory")!=0
					replace `f' = "factory" if strpos(`f',"factory")!=0
					tab `f' if strpos(`f',"production")!=0
					replace `f' = "factory" if strpos(`f',"production")!=0
					tab `f' if strpos(`f',"garment")!=0
					replace `f' = "factory" if strpos(`f',"garment")!=0
					replace `f' =  "factory" if `f' == "beverage (soft drink) sector" | `f' == "beverage" | `f' == "biscut masheg" ///
					| `f' == "bottle water packaging" | `f' == "cobilstone" | `f' == "cocacola distributer" | `f' == "coffee packaging" ///
					| `f' == "cutting flowdr" | `f' == "food complex" | `f' == "food complex manufacturing" | `f' == "food processing" 
					replace `f' = "factory" if `f' == "garement" | `f' == "germent" | `f' == "industry" | `f' == "kobel stone" | `f' == "leather" ///
					| `f' == "leather industry" | `f' == "leather shoes making" | `f' == "lesther industry" | `f' == "machin operator" ///
					| `f' == "machine operator" | `f' == "machin clenear" | `f' == "maintainance" | `f' == "manfactering" ///
					| `f' == "manufacturing of ceramics" | `f' == "mation operator" | `f' == "mechanic" | `f' == "metal" ///
					| `f' == "metal and woodwork" | `f' == "metal work" | `f' == "mileston" | `f' == "operator" ///
					| `f' == "textil t texu textile" | `f' == "textiel" | `f' == "garmet"
					replace `f' = "factory" if `f' == "packaging" | `f' == "packaging and printing" | `f' == "packaging industry" ///
					| `f' == "packaging materials poduction" | `f' == "packed water harvest" | `f' == "packing" ///
					| `f' == "packing water and fabricat botel" | `f' == "pakaging" | `f' == "paked water aqua addis" | `f' == "paking watr" ///
					| `f' == "plastic" | `f' == "plastic manufacturing" | `f' == "plastic shoes and goods manufacturing" ///
					| `f' == "produce carton" | `f' == "producton of plastic" | `f' == "prouction" | `f' == "ptoduction"
					replace `f'= "factory" if `f' == "shoe and sole prkduction" | `f' == "shoe making" | `f' == "shoe sole" ///
					| `f' == "soft drink" | `f' == "soft drink factroy" | `f' == "spring water" | `f' == "spring water bottling" ///
					| `f' == "steel and various products industry" | `f' == "t-shert" | `f' == "tanery" | `f' == "tannery" ///
					| `f' == "teraso prodact" | `f' == "tetile" | `f' == "textail" | `f' == "textail industry" | `f' == "textile" ///
					| `f' == "textile industry" | `f' == "textyl" | `f' == "water bottling" | `f' == "water harvest" ///
					| `f' == "water packaging" | `f' == "water packing" | `f' == "women wear" 
					replace `f'= "factory" if `f' == "anbasa shoe" | `f' == "blocket produce" | `f' == "building electrical instalation" ///
					| `f' == "soft drink" | `f' == "soft drink factroy" | `f' == "spring water" | `f' == "spring water bottling" ///
					| `f' == "harvest packed water" | `f' == "manufacturing plastic bag" | `f' == "manufering" | `f' == "metal work shop" ///
					| `f' == "teraso prodact" | `f' == "tetile" | `f' == "textail" | `f' == "textail industry" | `f' == "textile" ///
					| `f' == "metale work" | `f' == "package" | `f' == "soft drinks" | `f' == "tannri" | `f' == "cuttery" | `f' == "tailering"	///
					| `f' == "mirror lmporter" | `f' == "casher" | `f' == "printing press" | `f' == "tailor" | `f' == "tailer" 		///
					| `f' == "labratory" | `f' == "laborer" | `f' == "cotton washe" 
				replace `f' = proper(`f')
			}
			replace reg1sect_e = "Factory" if appid == 10480 & round == 1
			replace reg1sect_e = "Factory" if appid == 10391 & round == 1
			replace reg1sect_e = "Factory" if appid == 11506 & round == 1
			replace reg1sect_e = "Agriculture" if appid == 10679 & round == 1
			replace reg1sect_e = "Poultry Production" if appid == 10686 & round == 1
		gen stdy_firm = "Burayu Real Water" if projid == 101 | projid == 102
			replace stdy_firm = "Jittu Horticulture" if projid == 103
			replace stdy_firm = "Red Fox Farms" if projid == 104
			replace stdy_firm = "Anbesa Shoe" if projid == 106
			replace stdy_firm = "Maa Garment" if projid == 105 | projid == 107 | projid == 108
			la var stdy_firm "Study firm for this cohort"

		gen stdyfirm_m = 0
			la var stdyfirm_m "Months worked in study firm (from EL survey)"
			forvalues x = 1/6 {
				replace stdyfirm_m = stdyfirm_m + reg`x'work_e if reg`x'orgname_e == stdy_firm
			}
			qui replace stdyfirm_m = 11 if round == 1 & stdyfirm_m>11 & !missing(stdyfirm_m)
			qui replace stdyfirm_m = 12 if round == 2 & stdyfirm_m>12 & !missing(stdyfirm_m)
			qui replace stdyfirm_m = 13 if round == 3 & stdyfirm_m>13 & !missing(stdyfirm_m)
		/* With more liberal recoding */
		gen stdyfirm_m_lib = 0
			la var stdyfirm_m_lib "Months worked in study firm (from EL survey)"
			forvalues x = 1/6 {
				replace stdyfirm_m_lib = stdyfirm_m_lib + reg`x'work_e if reg`x'orgname_e == stdy_firm | reg`x'orgname_e == stdy_firm + " - Liberal"
			}
			qui replace stdyfirm_m_lib = 11 if round == 1 & stdyfirm_m_lib>11 & !missing(stdyfirm_m_lib)
			qui replace stdyfirm_m_lib = 12 if round == 2 & stdyfirm_m_lib>12 & !missing(stdyfirm_m_lib)
			qui replace stdyfirm_m_lib = 13 if round == 3 & stdyfirm_m_lib>13 & !missing(stdyfirm_m_lib)
			
		gen stdyfirmnow = 0
			la var stdyfirmnow "Currently working in study firm"
			replace stdyfirmnow = stdyfirm_m>=10
			
		gen stdyfirmnow_lib = 0
			la var stdyfirmnow_lib "Currently working in study firm, liberal recoding"
			replace stdyfirmnow_lib = stdyfirm_m_lib>=10
			
		gen anyfacfarm_w = 0 if found == 1
			la var anyfacfarm_w "Weeks worked in any factory or farm employing over 10 people (from EL survey, start and end dates)"
			forvalues x = 1/6 {
				replace anyfacfarm_w = anyfacfarm_w + reg`x'days_e/7 if (reg`x'sect_e == "Factory" | reg`x'sect_e == "Agriculture") & reg`x'workers_e>1 & !missing(reg`x'workers)
			}
			replace anyfacfarm_w = 4*11 if anyfacfarm_w> 4*11 & round == 1
			replace anyfacfarm_w = 4*12 if anyfacfarm_w> 4*12 & round == 2
			replace anyfacfarm_w = 4*13 if anyfacfarm_w> 4*13 & round == 3
		gen anyfacfarm_sec8_e = 0
			la var anyfacfarm_sec8_e "Months worked in any factory or farm employing over 10 people (from EL survey, Sec. 8)"
		gen anybigfirm_sec8_e = 0
			la var anybigfirm_sec8_e "Months worked in any firm employing over 10 people (from EL survey, Sec. 8)"
			forvalues x = 1/6 {
				replace anyfacfarm_sec8_e = anyfacfarm_sec8_e + reg`x'work_capped_e if (reg`x'sect_e == "Factory" | reg`x'sect_e == "Agriculture") & reg`x'workers_e>1 & !missing(reg`x'workers) & !missing(reg`x'work_e)
				replace anybigfirm_sec8_e = anybigfirm_sec8_e + reg`x'work_capped_e if reg`x'workers_e>1 & !missing(reg`x'workers) & !missing(reg`x'work_e)
			}
			gen anyfacfarm_m_e = anyfacfarm_sec8_e
				la var anyfacfarm_m_e "Months worked in any factory or farm employing over 10 people (from EL survey)"
			replace anyfacfarm_m_e = monthsworked_sec7_e if anyfacfarm_m_e == 0 & monthsworked_sec7_e != 0 & monthsworked_sec7_e != .
			replace anyfacfarm_m_e = (monthsworked_sec7_e + anyfacfarm_sec8_e)/2 if anyfacfarm_sec8_e != 0 & monthsworked_sec7_e != 0
			replace anyfacfarm_m_e = 12 if anyfacfarm_m_e>12 & !missing(anyfacfarm_m_e)
			replace anyfacfarm_m_e = . if found != 1
			
			// Do the same for any large firm
			gen anybigfirm_m_e = anybigfirm_sec8_e
				la var anybigfirm_m_e "Months worked in any factory or farm employing over 10 people (from EL survey)"
			replace anybigfirm_m_e = monthsworked_sec7_anyfirm if anybigfirm_m_e == 0 & monthsworked_sec7_anyfirm != 0 & monthsworked_sec7_anyfirm != .
			replace anybigfirm_m_e = (monthsworked_sec7_anyfirm + anybigfirm_sec8_e)/2 if anybigfirm_sec8_e != 0 & monthsworked_sec7_anyfirm != 0
			replace anybigfirm_m_e = 12 if anybigfirm_m_e>12 & !missing(anybigfirm_m_e)
			replace anybigfirm_m_e = . if found != 1
			
			// Create variable for large, non-industrial firm
			gen anynonindustrialfirm_m_e = anybigfirm_m_e - anyfacfarm_m_e
			la var anynonindustrialfirm_m_e "Months of formal employment in any non-industrial firm in the past year"
			
			gen anynonindustrialfirm_e = (anynonindustrialfirm_m_e!=0) if !missing(anynonindustrialfirm_m_e)
			replace anynonindustrialfirm_e = . if found!=1
			label var anynonindustrialfirm_e "Worked at least 30 days in any non-industrial firm > 10 employees, from section 7 and 8"
			
		gen anyfacfarm_sec8_anysize_e = 0
		la var anyfacfarm_sec8_anysize_e "Months worked in any factory or farm (from EL survey, Sec8)"
			forvalues x = 1/6 {
				replace anyfacfarm_sec8_anysize_e = anyfacfarm_sec8_anysize_e + reg`x'work_capped_e if (reg`x'sect_e == "Factory" | reg`x'sect_e == "Agriculture") & !missing(reg`x'work_e)
			}
		gen anyfacfarm_anysize_e = anyfacfarm_sec8_anysize_e
			la var anyfacfarm_anysize_e "Months worked in any factory or farm (from EL survey)"
			replace anyfacfarm_anysize_e = monthsworked_sec7_anysize_e if anyfacfarm_anysize_e == 0 & monthsworked_sec7_anysize_e != 0 & monthsworked_sec7_anysize_e != .
			replace anyfacfarm_anysize_e = (monthsworked_sec7_anysize_e + anyfacfarm_sec8_anysize_e)/2 if anyfacfarm_sec8_anysize_e != 0 & monthsworked_sec7_anysize_e != 0			
			replace anyfacfarm_anysize_e = 12 if anyfacfarm_anysize_e>12 & !missing(anyfacfarm_anysize_e)
			replace anyfacfarm_anysize_e = . if found != 1
		qui replace monthsworked_sec7_anysize_e = 0 if missing(monthsworked_sec7_anysize_e)
			
			
		gen longestfacfarm_w = 0
			la var longestfacfarm_w "Weeks worked in any factory or farm employing over 10 people (from EL survey) where worked longest"
			replace longestfacfarm_w = reg1days_e/7 if (reg1sect_e == "Factory" | reg1sect_e == "Agriculture") & reg1workers_e>1 & !missing(reg1workers)
		gen anyfirm_m = 0
			la var anyfirm_m "Months worked in any firm employing over 10 people (from EL survey)"
			forvalues x = 1/6 {
				replace anyfirm_m = anyfirm_m + reg`x'work_e if reg`x'workers_e>1 & !missing(reg`x'workers)
			}
	/* Merge in attrition database, this covers P101-106 */

		merge m:1 appid using "$ILEdata/raw/MonAttritcContam_Database.dta"
		ren _merge _merge_att	
		
		preserve
			import excel "$ILEdata/raw/Reasons for not surveyed.xlsx", first clear
			rename Appid appid
			replace F = mIND if missing(F)
			/* Migrated */
			gen mig11 = strpos(mIND,"igrat")!=0 if Projid >= 102
			gen mig12 = strpos(mIND,"igrat")!=0 if Projid == 101
			gen mig13 = strpos(F,"igrat")!=0 if Projid >= 102
			/* Refused */
			gen ref11 = strpos(mIND,"efus")!=0 if Projid >= 102
			gen ref12 = strpos(mIND,"efus")!=0 if Projid == 101
			gen ref13 = strpos(F,"efus")!=0 if Projid >= 102
			/* Lost */
			gen lost11 = strpos(mIND,"an't find")!=0 if Projid >= 102
			gen lost12 = strpos(mIND,"an't find")!=0 if Projid == 101
			gen lost13 = strpos(F,"an't find")!=0 if Projid >= 102		
			/* Died */
			gen died11 = strpos(mIND,"Died")!=0 if Projid >= 102
			gen died12 = strpos(mIND,"Died")!=0 if Projid == 101
			gen died13 = strpos(F,"Died")!=0 if Projid >= 102	
			/* Prison */
			gen prison11 = strpos(mIND,"Prison")!=0 if Projid >= 102
			gen prison12 = strpos(mIND,"Prison")!=0 if Projid == 101
			gen prison13 = strpos(F,"Prison")!=0 if Projid >= 102	
			/* Other reason */
			gen other11 = (strpos(mIND,"No Reason")!=0 | strpos(mIND,"SeeComment")!=0) if Projid >= 102
			gen other12 = (strpos(mIND,"No Reason")!=0 | strpos(mIND,"SeeComment")!=0) if Projid == 101
			gen other13 = (strpos(mIND,"No Reason")!=0 | strpos(mIND,"SeeComment")!=0) if Projid >= 102			
			keep appid mig1* ref1* lost1* died1* prison1* other1*
			saveold "$ILEdata/raw/ILE_Attrition_Data.dta", replace 
		restore
		merge m:1 appid using "$ILEdata/raw/ILE_Attrition_Data.dta", nogen
		
	/* Merge in P107& P108 */
	
		merge m:1 appid using "$ILEdata\raw\P107&108_contamination_list.dta", gen(_merge_att2) update
			drop if _merge_att2 == 2 /* There is one blank observation that we are removing */
		
// 3. TREATMENT AND TREATMENT DEFINITIONS //
	
	//a. Treatment variable
		
		// Replacement hiring
			
			// Label Treatment_b, which is original treatment assignment from randomization 
				la var treatment_b "Available positions"
			
			// Create a new variable for treatment assignment with control replacements
				gen treatment_br = (treatment_b)
				replace treatment_br=1 if orig_treatment_att=="Job (Replacement)"
					la var treatment_br "Treatment assignment (with control replacements)"		
		
		// Treatment variable based on original assignment
		
				gen job=(treatment_b==1)
					la var job "Assignment to Treatment: formal sector job"
							
				gen ngo=(treatment_b==2)
					la var ngo "Assignment to Treatment: grant and training"
							
				gen pcg=(treatment_b==0)
					la var pcg "Assignment to Pure control group"
					
				gen assigned_any = (treatment_b == 1 | treatment_b == 2)
					la var assigned_any "Assigned to Any Treatment"

	// b. Cleaning to construct treatment definitions for TOT/IV estimation

			// i. If worked in research site provided job (ILE job) for at least 1 month =1, otherwise =0 
				
				// Computing days worked in ILE job (using attrition and contamination data)
						
					split start_date_att, p(/)
					ren start_date_att1 mo1
					ren start_date_att2 da1
					ren start_date_att3 yr1
		 
					split depart_date_att, p(/)
					ren depart_date_att1 mo2
					ren depart_date_att2 da2
					ren depart_date_att3 yr2
					
					replace yr2="2011" if yr2=="11"
					replace yr2="2012" if yr2=="12"
					
					foreach x in mo1 da1 yr1 yr2 mo2 da2 {
					destring `x', replace
					}

					gen A=(da2-da1)*1
					gen B=(mo2-mo1)*30
					gen C=(yr2-yr1)*360
					
					replace daysilejob_att=A+B+C if projid < 107

					drop da1 da2 mo1 mo2 yr1 yr2 A B C
				
					gen ilejob1=job
								
				replace ilejob1=0 if refused_att==1 & job==1 // Refused job treatment
				replace ilejob1=1 if contaminated_att==1 // Contamination: control group getting job in ILE factory 
				replace ilejob1=0 if daysilejob_att<30 // Less than 30 days
				la var ilejob1 "Received a treatment job (at least 1 month)"
					
			// ii. IGC (for replication), factory job at least 8 hours per day and at least one month in 12 months 
				
				gen facjob1=cond(fachoursday_e>7.99 & fac12months_e>0.99 & fachoursday_e<. & fac12months_e<. , 1, 0)
				la var facjob1 "Worked full time in factory job at least 1 month"	
					
	// c. looping dummies for treatment definitions
					
		global igacateg psnp farm share animal farmwage food shop trade voc tailor crafts fac casual ///
			mining driver sec soldier dom clerical famwork wait teach othwork1 othwork2 othwork3
			
					foreach x in $igacateg {			
					gen w_`x'=cond(`x'12months_e!=0 & `x'12months_e!=., 1, 0)
					
				// WORK FOR 
					gen workfor_self_`x'=cond(`x'workfor_e==1, 1, 0)
						replace workfor_self_`x'=. if `x'workfor_e==.
					gen workfor_other_`x'=cond(`x'workfor_e==2, 1, 0)
						replace workfor_other_`x'=. if `x'workfor_e==.
					gen workfor_both_`x'=cond(`x'workfor_e==3, 1, 0)
						replace workfor_both_`x'=. if `x'workfor_e==.
					
				// PAYMENT REGULARITY -- NO 101 data
					gen pay_reg_`x'=cond(`x'payment_e==4 | `x'payment_e==5 | `x'payment_e==6, 1, 0)
						replace pay_reg_`x'=. if `x'payment_e==.
					gen pay_irreg_`x'=cond(`x'payment_e==1 | `x'payment_e==2, 1, 0)
						replace pay_irreg_`x'=. if `x'payment_e==.
					
				// LENGTH/CERTAINTY -- NO 101 data
					gen length_certshort_`x'=cond(`x'length_e==1, 1, 0)
						replace length_certshort_`x'=. if `x'length_e==. 
					gen length_certlong_`x'=cond(`x'length_e==2, 1, 0)
						replace length_certlong_`x'=. if `x'length_e==. 
					gen length_uncertshort_`x'=cond(`x'length_e==3, 1, 0)
						replace length_uncertshort_`x'=. if `x'length_e==. 
					gen length_uncertlong_`x'=cond(`x'length_e==4, 1, 0)
						replace length_uncertlong_`x'=. if `x'length_e==. 
					
				// SIZE OF ORG 	
					replace `x'size_e=3 if `x'size_e==4
					
					gen size_micro_`x'=cond(`x'size_e==1, 1, 0)
						replace size_micro_`x'=. if `x'size_e==.
					gen size_small_`x'=cond(`x'size_e==2, 1, 0)
						replace size_small_`x'=. if `x'size_e==.
					gen size_medium_`x'=cond(`x'size_e==3, 1, 0)
						replace size_medium_`x'=. if `x'size_e==.
					gen size_large_`x'=cond(`x'size_e==5, 1, 0)
						replace size_large_`x'=. if `x'size_e==.
					
				// INTENSITY OF EMPLOYMENT
					
					// HOURS PER DAY, USUAL IN YEAR 
						gen hoursday_a8_`x'=cond(`x'hoursday_e>7.9, 1, 0)
							replace hoursday_a8_`x'=. if `x'hoursday_e==.
						
					// DAYS PER MONTH, USUAL IN YEAR 
						gen daysmonth_a25_`x'=cond(`x'daysmonth_e>25, 1, 0)
							replace daysmonth_a25_`x'=. if `x'daysmonth_e==.
						
					// HOURS PER DAY, past 7 days 
						gen hoursday7_a8_`x'=cond(`x'7hours_e>7.9, 1, 0)
							replace hoursday7_a8_`x'=. if `x'7hours_e==.
						
					// DAYS PER WEEK, past 7 days 
						gen daysweek7_a6_`x'=cond(`x'7days_e>5.9, 1, 0)
							replace daysweek7_a6_`x'=. if `x'7days_e==.

					// HOURS PER DAY, past 7 days, before 7 -- NO 101 data
						gen hoursday77_a8_`x'=cond(`x'14hours_e>7.9, 1, 0)
							replace hoursday77_a8_`x'=. if `x'14hours_e==.
						
					// DAYS PER WEEK, past 7 days, before 7 -- NO 101 data
						gen daysweek77_a6_`x'=cond(`x'14days_e>5.9, 1, 0)
							replace daysweek77_a6_`x'=. if `x'14days_e==.
				
				// KEY TREATMENT DEFINITIONS //
				
					gen treatdef_`x'=cond(workfor_other_`x'==1, 1, 0)								// 1 if work for other
					replace treatdef_`x'=. if workfor_other_`x'==.									// Missing observations (.)
					
					replace treatdef_`x'=0 if length_certshort_`x'==1 | length_uncertshort_`x'==1	// 0 if short
					replace treatdef_`x'=0 if size_micro_`x'==1										// 0 if micro firm
					
					replace treatdef_`x'=. if length_certshort_`x'==. & length_uncertshort_`x'==.
					replace treatdef_`x'=. if size_micro_`x'==.		
				}
	
				// BURAYU 101
				
					* Burayu 101 has missing data for length_certshort & length_uncertshort; so the Burayu 101 definition is more lenient
					
	// d. Compliance definitions
		// Job
			// offer = assigned - unreachable 
				gen offer =(treatment_b==1) 
					replace offer = 1 if orig_treatment_att=="Job (Replacement)" 
					replace offer = 0 if unreachable_att == 1 
					la var offer "Offered a job in a treatment firm"
			
			/* New "compliance" variables */
			/* The data comes from 2 different sources */
			gen treatmentfirm_1d = (((treatment_b == 1 & unreachable_att!=1 & fired != 1 & refused != 1) | contaminated_att == 1) & daysilejob_att>=1) if projid<107
				replace treatmentfirm_1d = daysilejob_att>=1 if projid >= 107
				la var treatmentfirm_1d "Worked in treatment firm for at least 1 day"
			/* Do the same for 30 days */
			gen treatmentfirm_30d = (((treatment_br == 1 & unreachable_att!=1 & fired != 1 & refused != 1) | contaminated_att == 1) & daysilejob_att>=30) if projid<107
				replace treatmentfirm_30d = daysilejob_att>=30 if projid >= 107
				la var treatmentfirm_30d "Worked in treatment firm for at least 30 days"
				
			/* Make slight correct to 1d indicator */
			replace treatmentfirm_1d = 1 if treatmentfirm_30d==1
		
			gen declinedjob = treatmentfirm_1d==0 if treatment_br == 1
				la var declinedjob "Did not show up for one day of the treatment job"
			gen under30djob = treatmentfirm_30d==0 if treatment_br == 1
				la var under30djob "Declined job offer or did not work at treatment firm for more than a month"
		
		// NGO 
			
				gen offer_n = (treatment_b==2)
					replace offer_n = 0 if  unreachable_att == 1 
					la var offer_n "Offered treatment: grant and training" 
					
				gen accept_n = (offer_n)
					replace accept_n = 0 if refused_att == 1
					la var accept_n "Accepted grant and training treatment" 
					
				gen receive_n = (accept_n) 
					replace receive_n = 0 if noncompliant_att == 1
					la var receive_n "Received grant and training treatment"

		// Control
				gen offer_pcg = (treatment_b==0)
				la var offer_pcg "Offered treatment: control" 

		// Treatment definition 1: work for other, considered long, >10 employees 
			egen treatdef1=anymatch(treatdef_*), values(1)
				replace treatdef1 = . if found != 1
				label var treatdef1 "Worked at least 30 days in any firm with > 10 employees"
			// Alternate version with section 7 and 8 reconciled
			gen anybigfirm_e = (anybigfirm_m_e!=0) if !missing(anybigfirm_m_e)
				replace anybigfirm_e = . if found!=1
				label var anybigfirm_e "Worked at least 30 days in any firm > 10 employees, from section 7 and 8"
				
		// Treatment definition 2: work for other, considered long, >10 employees (ONLY farm or factory) 
			egen treatdef2=anymatch(treatdef_fac treatdef_farmwage), values(1) 
				replace treatdef2 = 1 if treatmentfirm_30d == 1 // includes job takers who have worked for at least 30 days according to firm's records
				label var treatdef2 "Worked at least 30 days in any factory or farm > 10 employees"
		// Treatment definition 3: work for other, considered long, >10 employees (ONLY farm or factory)  from sections 7 AND 8
			gen treatdef3=(anyfacfarm_m_e!=0) if !missing(anyfacfarm_m_e)
				replace treatdef3 = . if found!=1
				label var treatdef3 "Worked at least 30 days in any factory or farm > 10 employees, from section 7 and 8"
	

// 12. DEFLATE NOMINAL BIRR VARIABLES
	/* Save CPIs */
	local cpi2010mar "66.27285"
	local cpi2010nov "72.20653"
	local cpi2011apr "86.21097"
	local cpi2011sep "98.02833"
	local cpi2011oct "99.82872"
	local cpi2011nov "99.6215"
	local cpi2012jan "102.3"
	local cpi2012may "111.7"
	local cpi2012sep "117.3"
	local cpi2012oct "116.3"
	local cpi2012nov "115.9"
	local cpi2012dec "115"
	local cpi2013jan "115.3"
	local cpi2013apr "117.5"
	local cpi2013may "118.7"
	local cpi2013jun "119.6"
	local cpi2013dec "123.8"
	local cpi2014feb "125.1"
	local cpi2014apr "128.2"
	local cpi2014jun "129.8"
	local cpi2014aug "131.4"
	local cpiBASE = "`cpi2010mar'"
	/* For baseline variables */
	foreach v in totalprofit7_av_b incdiff12_permon_b save4weeks_b debttotal_b ///
	mid12months_b incdiff30_b incdiff12_b cash4weeks_b {
		qui replace `v' = `v'/`cpi2010mar'*`cpiBASE' if projid == 101
		qui replace `v' = `v'/`cpi2010nov'*`cpiBASE' if projid == 102
		qui replace `v' = `v'/`cpi2011sep'*`cpiBASE' if projid == 103
		qui replace `v' = `v'/`cpi2011oct'*`cpiBASE' if projid == 104
		qui replace `v' = `v'/`cpi2012may'*`cpiBASE' if projid == 105
		qui replace `v' = `v'/`cpi2013jan'*`cpiBASE' if projid == 106
		qui replace `v' = `v'/`cpi2013may'*`cpiBASE' if projid == 107
		qui replace `v' = `v'/`cpi2013jun'*`cpiBASE' if projid == 108
		/* Relabel to note deflation */
		local lab: var lab `v'
		la var `v' "`lab' (mar2010 birr)"
	}
	/* For endline variables */
	foreach v in cash4weeks_e totalprofit7_av_e incdiff12_e cons_month_e ///
		nonfoodpc_e foodpc_e conspc_e totalprofit_7d_e totalprofit_7d7_e totalcash_7d_e ///
		totalcash_7d7_e mid12months_e incdiff12_permon_e		///
		cash7days_e save7days_e contributehh4weeks_e contributehh7days_e 		///
		educ_4months_e educ_birr_e incdiff30_e mid30days_e save4weeks_e debttotal_e 	    ///
		totalcash7_av_e net_trans_e cash_1w_e psnp_profithour_e farm_profithour_e    ///
		share_profithour_e animal_profithour_e farmwage_profithour_e food_profithour_e ///
		shop_profithour_e trade_profithour_e voc_profithour_e tailor_profithour_e crafts_profithour_e ///
		fac_profithour_e casual_profithour_e mining_profithour_e driver_profithour_e sec_profithour_e ///
		soldier_profithour_e dom_profithour_e clerical_profithour_e famwork_profithour_e ///
		wait_profithour_e teach_profithour_e othwork1_profithour_e othwork2_profithour_e othwork3_profithour_e {
		/* For 12 month */
		qui replace `v' = `v'/`cpi2011apr'*`cpiBASE' if projid == 101 & round == 2
		/* For 11 month */
		qui replace `v' = `v'/`cpi2011nov'*`cpiBASE' if projid == 102 & round == 1
		qui replace `v' = `v'/`cpi2012sep'*`cpiBASE' if projid == 103 & round == 1
		qui replace `v' = `v'/`cpi2012oct'*`cpiBASE' if projid == 104 & round == 1
		qui replace `v' = `v'/`cpi2013apr'*`cpiBASE' if projid == 105 & round == 1
		qui replace `v' = `v'/`cpi2013dec'*`cpiBASE' if projid == 106 & round == 1
		qui replace `v' = `v'/`cpi2014apr'*`cpiBASE' if projid == 107 & round == 1
		qui replace `v' = `v'/`cpi2014jun'*`cpiBASE' if projid == 108 & round == 1
		/* For 13 month */
		qui replace `v' = `v'/`cpi2012jan'*`cpiBASE' if projid == 102 & round == 3
		qui replace `v' = `v'/`cpi2012nov'*`cpiBASE' if projid == 103 & round == 3
		qui replace `v' = `v'/`cpi2012dec'*`cpiBASE' if projid == 104 & round == 3
		qui replace `v' = `v'/`cpi2013jun'*`cpiBASE' if projid == 105 & round == 3
		qui replace `v' = `v'/`cpi2014feb'*`cpiBASE' if projid == 106 & round == 3
		qui replace `v' = `v'/`cpi2014jun'*`cpiBASE' if projid == 107 & round == 3
		qui replace `v' = `v'/`cpi2014aug'*`cpiBASE' if projid == 108 & round == 3	
		/* Relabel to note deflation */
		local lab: var lab `v'
		la var `v' "`lab' (mar2010 birr)"
	}

// 13. DATA IMPUTATIONS AND CORRECTIONS //

	// a. Impute medians for missing control data
		
		foreach x in exactage_b single_b male_b female_b r_muslim_b dep_worker_b all_math_b educ_b ///
		totalprofit7_av_b consdur_b proddur_b fac1_b aghours_1w_b cashours_1w_b ///
		facthours_1w_b pettybusnhours_1w_b skilledhours_1w_b wagelowhours_1w_b ///
		wagemedhours_1w_b othhours_1w_b incdiff12_permon_b save4weeks_b borr3000bus_b ///
		healthproblems_b riskaversion_b patience_b locuscontrol_b selfesteem_b ///
		selfcontrol_b finsecondary_b illit_b famsupport_b commsupport_b debttotal_b stat_change1_b ///
		phqtotal_b gadtotal_b phqtotal_r_b gadtotal_r_b agression_b consc_b fac_expery_b shop_expery_b state_expery_b ngo_expery_b ///
		becomeill_b likely_betterjob_b likely_regwork_b mid12months_b incdiff30_b incdiff12_b translator_b ///
		age2_b age3_b age4_b agexper_mo_b casexper_mo_b factexper_mo_b pettybusnexper_mo_b skilledexper_mo_b ///
		wagelowexper_mo_b wagemedexper_mo_b othexper_mo_b psnpexper_mo_b hhsize_b head_b  executive_score_b ///
		riskaversion_all_b riskaversion_ibm_b patience_all_b patience_ibm_b timeinc_ibm_b prob_betterjob_b prob_regwork_b ///
		cash4weeks_b cog_overall_index mentalhealth_index success_index_b formal_expery_b optimism_index_b nowork_4weeks_b hourswork_wk_b ///
		aghours_wk_b cashours_wk_b facthours_wk_b pettybusnhours_wk_b skilledhours_wk_b wagelowhours_wk_b wagemedhours_wk_b othhours_wk_b disabled_b ///
		facfarm_b factory_b workexper_mo workexper2_mo fac_expery_b regwork_nofac_exper_b {
				sum `x', d
				replace `x' = r(p50) if missing(`x') 
			}		
			
	// b. Seemingly erroneous variables corrected

 		replace farmworkfor_e=2 if surveyid==102033
 		replace sharesize_e=1 if surveyid==103411
 		replace vocworkfor_e=2 if surveyid==104763 
 		replace facworkfor_e=2 if facsize_e>1 & facsize_e<6
 		replace casualworkfor_e=2 if casualsize_e>1 & casualsize_e<6
 		replace othwork1workfor_e=2 if othwork1size_e>1 & othwork1size_e<6
		
	// c. Fix other outlier values
			
			foreach var of varlist hourswork*_e { 
				replace `var'=. if appid==10029 
			}

	// d. Volatility measure construction (for descriptive tables - can move this to construction file after reorganizing dofiles)
		
		// From General Employment section 
		
			// Profit earned: Past week (7d) and week before past week (7d7) profit measure for 11 and 13 month endlines
				
				bysort appid: egen vtotalprofit7d_e1e2_e =mean(totalprofit_7d_e) if found_ei1==1 | found_ei2==1
					lab var vtotalprofit7d_e1e2 "Volatility: Avg earnings past week: IGAs"				
	 		
				bysort appid: egen vtotalprofit7d7_e1e2_e =mean(totalprofit_7d7_e) if found_ei1==1 | found_ei2==1
					lab var vtotalprofit7d7_e1e2 "Volatility: Avg week before past week (IGAs)"				
					
				egen vtotalprofit_14d_e1e2_e = rowmean(vtotalprofit7d_e1e2 vtotalprofit7d7_e1e2) if found_ei1==1 | found_ei2==1
					lab var vtotalprofit_14d_e1e2_e "Volatility: Avg earnings by two sets of two weeks: IGAs"

			// Cash earned: Past week (7d) and week before past week (7d7) cash measure for 11 and 13 month endlines
				
				bysort appid: egen vtotalcash7d_e1e2_e =mean(totalcash_7d_e) if found_ei1==1 | found_ei2==1
					lab var vtotalcash7d_e1e2_e "Volatility: Avg cash past week: IGAs"				
	 		
				bysort appid: egen vtotalcash7d7_e1e2_e =mean(totalcash_7d7_e) if found_ei1==1 | found_ei2==1
					lab var vtotalcash7d7_e1e2_e "Volatility: Avg cash week before past week (IGAs)"				
					
				egen vtotalcash_14d_e1e2_e = rowmean(vtotalcash7d_e1e2 vtotalcash7d7_e1e2) if found_ei1==1 | found_ei2==1
					lab var vtotalcash_14d_e1e2_e "Volatility: Avg cash by two sets of two weeks: IGAs"

				egen vtotalcash_4wks_e1e2_e = rowtotal(vtotalcash7d_e1e2 vtotalcash7d7_e1e2) if found_ei1==1 | found_ei2==1, m
					lab var vtotalcash_4wks_e1e2_e "Volatility: Avg total cash 4 weeks 2 sets of 2 weeks: IGAs"
					
			// Days worked 
		
				bysort appid: egen vdayswork_7d_e1e2_e =mean(dayswork_7day_e)	if found_ei1==1 | found_ei2==1		
					lab var vdayswork_7d_e1e2_e "Volatility: Total days worked in the past 7 days"
				
				bysort appid: egen vdayswork_7d7_e1e2_e =mean(dayswork_7day7_e)	if found_ei1==1 | found_ei2==1			
					lab var vdayswork_7d7_e1e2_e "Volatility: Total days worked in the 7 days before the past 7 days"
					
				egen vdayswork_2wk_e1e2_e = rowmean(vdayswork_7d_e1e2 vdayswork_7d7_e1e2) if found_ei1==1 | found_ei2==1
					lab var vdayswork_2wk_e1e2_e "Volatility: Total days worked in the past 2 weeks"

				bysort appid: egen vdayswork_4wk_e1e2_e =mean(dayswork_4wk_e) if found_ei1==1 | found_ei2==1				
					lab var vdayswork_4wk_e1e2_e "Volatility: Total days worked in the past 4 weeks"
					
			// Hours worked

				bysort appid: egen vhourswork_7d_e1e2_e =mean(hourswork_7d_e)	if found_ei1==1 | found_ei2==1		
					lab var vhourswork_7d_e1e2_e "Volatility: Total hours worked in the past 7 days"
				
				bysort appid: egen vhourswork_7d7_e1e2_e =mean(hourswork_7d7_e)	if found_ei1==1 | found_ei2==1			
					lab var vhourswork_7d7_e1e2_e "Volatility: Total hours worked in the 7 days before the past 7 days"
									
				egen vhourswork2wk_e1e2_e = rowmean(vhourswork_7d_e1e2 vhourswork_7d7_e1e2) if found_ei1==1 | found_ei2==1
					lab var vhourswork2wk_e1e2_e "Volatility: Avg hours worked in the past 2 weeks per week"

				bysort appid: egen vhourswork_4wk_e =mean(hourswork_4wk_e)	if found_ei1==1 | found_ei2==1			
					lab var vhourswork_4wk_e "Volatility: Total hours worked in the past 4 weeks"
					
		// From Cash & Savings section 
	
			// Cash earned: Past 4 weeks (from Cash & Savings section) in 11 and 13m endline 
				
				bysort appid: egen vcs_cash4weeks_e1e2_e =mean(cash4weeks_e) if found_ei1==1 | found_ei2==1
				lab var vcs_cash4weeks_e1e2_e "Volatility: Avg of two months earnings: Cash and Savings"
				
			// Cash earned: Past 7 days (from Cash & Savings section) in 11 and 13m endline 
			
				bysort appid: egen vcs_cash7days_e1e2_e =mean(cash7days_e) if found_ei1==1 | found_ei2==1
				lab var vcs_cash7days_e1e2_e "Volatility: Avg of two weeks earnings: Cash and Savings"

	// f. Fixing outliers (upper censor, inverse sine and natural log). 

		// endline
	
			foreach x in cash4weeks techhours unihours trainhours ///
			totalprofit7_av workcond hourswork_1w incdiff12 consdur proddur cons_month nonfoodpc foodpc ///
			conspc totalprofit_7d7 totalprofit_7d totalcash_7d7 totalcash_7d becomeill mid12months incdiff12_permon cashhour7 cash7days save7days hourswork  ///
			contributehh4weeks contributehh7days hourstraining healthproblems phqtotal educ_4months aghoursoth_1w /// 
			aghourscom_1w cashours_1w facthours_1w pettybusnhours_1w educ_birr educ daytraining gadtotal incdiff30 mid30days ///
			likely_betterjob likely_regwork agression save4weeks debttotal net_trans tech_any uni_any train_any skilledhours_1w ///
			wagelowhours_1w wagemedhours_1w othhours_1w daystraining higheduc_hh stat_change1 totalcash7_av status ///
			vdayswork_7d_e1e2 vdayswork_7d7_e1e2 vdayswork_2wk_e1e2 vdayswork_4wk_e1e2 vhourswork_7d_e1e2 vhourswork_7d7_e1e2 ///
			vhourswork2wk_e1e2 vhourswork_4wk vtotalcash7d_e1e2 vtotalcash7d7_e1e2 vtotalcash_14d_e1e2 vcs_cash4weeks_e1e2 ///
			vcs_cash7days_e1e2 vtotalcash_4wks_e1e2  timeuse_leisure timeuse_commute timeuse_domestic aghoursoth_7d7 ///
			aghourscom_7d7 casualhours_7d7 facthours_7d7 pettybusnhours_7d7 skilledhours_7d7 wagelowhours_7d7 wagemedhours_7d7 othhours_7d7 aghoursoth_7d ///
			aghourscom_7d casualhours_7d facthours_7d pettybusnhours_7d skilledhours_7d wagelowhours_7d wagemedhours_7d othhours_7d hourswork_7d hourswork_7d7 ///
			cash_1w hourswork_wk aghoursoth_wk aghourscom_wk cashours_wk facthours_wk pettybusnhours_wk skilledhours_wk ///
			wagelowhours_wk wagemedhours_wk othhours_wk {

				local lbl: variable label `x'_e
				gen `x'_p99_e =`x'_e if (found_ei1==1 | found_ei2==1)		    // 99% cutoff
				gen `x'_ihs_e = ln(`x'_e+(`x'_e^2+1)*1/2) 	// inverse hyperbolic sine transformation	
				gen `x'_ln_e  = ln(`x'_e + 1)			    // natural log (plus one)
				
				qui sum `x'_p99_e,d
				replace `x'_p99_e=r(p99) if `x'_p99_e>r(p99) & `x'_p99_e!=. & (found_ei1==1 | found_ei2==1)
				
				la var `x'_p99_e "P99: `lbl'"
				la var `x'_ihs_e "INVERSE SINE: `lbl'"
				la var `x'_ln_e "LOG: `lbl'"
				}
		// Capping "rare" outcomes
		foreach x in psnphours_1w {
				local lbl: variable label `x'_e
				gen `x'_p99_e =`x'_e if (found_ei1==1 | found_ei2==1)
				qui sum `x'_p99_e if `x'_p99_e != 0, d
				replace `x'_p99_e=r(p99) if `x'_p99_e>r(p99) & `x'_p99_e!=. & (found_ei1==1 | found_ei2==1)
				la var `x'_p99_e "P99: `lbl'"
		}
		
		// baseline
			foreach x in exactage age2 age3 age4 dep_worker all_math educ totalprofit7_av hourstraining aghours_1w cashours_1w facthours_1w ///
			pettybusnhours_1w skilledhours_1w wagelowhours_1w othhours_1w incdiff12 consdur proddur save4weeks borr3000bus ///
			incdiff12_permon healthproblems riskaversion patience locuscontrol selfesteem selfcontrol hourswork_1w debttotal agexper_mo 	///
			casexper_mo factexper_mo pettybusnexper_mo skilledexper_mo wagelowexper_mo wagemedexper_mo othexper_mo psnpexper_mo psnphours_1w ///
			cash4weeks aghourscom_1w aghoursoth_1w hourswork hourswork_wk nowork_2weeks aghours_wk aghoursoth_wk aghourscom_wk cashours_wk 					///
			facthours_wk pettybusnhours_wk skilledhours_wk wagelowhours_wk wagemedhours_wk othhours_wk aghours cashours facthours ///
			pettybusnhours skilledhours wagelowhours wagemedhours othhours workexper_mo workexper2_mo fac_expery regwork_nofac_exper { 
		
				local lbl: variable label `x'_b
				gen `x'_p99_b =`x'_b					    // 99% cutoff
				gen `x'_ihs_b = ln(`x'_b+(`x'_b^2+1)*1/2) 	// inverse hyperbolic sine transformation	
				gen `x'_ln_b  = ln(`x'_b + 1)			    // natural log (plus one)
						
				qui sum `x'_p99_b,d
				replace `x'_p99_b=r(p99) if `x'_p99_b>r(p99) & `x'_p99_b!=.
						
				la var `x'_p99_b "P99: `lbl'"
				la var `x'_ihs_b "INVERSE SINE: `lbl'"
				la var `x'_ln_b "LOG: `lbl'"						
				}
	
	// Capping "rare" baselines
		foreach x in wagemedhours_1w {
				local lbl: variable label `x'_b
				gen `x'_p99_b =`x'_b
				qui sum `x'_p99_b if `x'_p99_b != 0, d
				replace `x'_p99_b=r(p99) if `x'_p99_b>r(p99) & `x'_p99_b!=.
				la var `x'_p99_b "P99: `lbl'"
		}
	// g. Standardize (z-score)
		
		// endline
   foreach x in cons_month_p99 conspc_p99 consdur_p99 proddur_p99 hourswork_p99 totalprofit7_av_p99 incdiff12_p99 	///
   laddnow laddyearago laddnxtyear status stat_change1 stat_change2 stat_change3 workcond healthproblems 	///
   phqtotal_r phqtotal workcond_p99 gadtotal_r gadtotal agression currentschool daytraining hourstraining totalcash_7d7 foodpc 	///
   cash4weeks_p99 cash7days_p99 techhours_p99 unihours_p99 trainhours_p99 educ_birr_p99 risk_ill 			///
   risk_betterjob risk_regwork mid30days_p99 risk_mid30 risk2 mid12months_p99 risk_mid12 incdiff30_p99 		///
   anxiety indperception incdiff12_permon_p99 {
  
    local lbl : variable label `x'_e
    egen `x'_std_e = std(`x'_e) if wave == 1
    egen `x'_std_2_e = std(`x'_e) if wave == 2
    replace `x'_std_e = `x'_std_2_e if wave==2
    drop `x'_std_2_e
    replace `x'_std_e=. if `x'_e==.
    la var `x'_std_e "`lbl' (Z-Score)"
   }
     
  // baseline
   foreach x in totalprofit7_av_p99 incdiff12_p99 incdiff12_permon_p99 totalcash7d7 totalprofit7d7 hourstraining_p99 ///
   exactage_p99 age2 r_orthodox male dep_worker single educ all_math consdur_p99 proddur_p99 healthproblems laddnow status 	///
   locuscontrol_p99 selfcontrol_p99 selfesteem_p99 famsupport commsupport phqtotal gadtotal phqtotal_r 	gadtotal_r 	///
   agression consc { 
 
    local lbl : variable label `x'_b
    egen `x'_std_b = std(`x'_b)
    replace `x'_std_b=. if `x'_b==.
    la var `x'_std_b "`lbl' (Z-Score)" 
   }		
	
	
*******************************************
*** 14. CREATE VOLATILITY MEASURES ********
*******************************************

	foreach c in hourswork aghoursoth aghourscom casualhours facthours pettybusnhours skilledhours wagelowhours wagemedhours othhours totalcash totalprofit {
			egen `c'_tot = rowtotal (`c'_7d_p99_e `c'_7d7_p99_e), m
			egen `c'_count = count(`c'_tot), by(appid)
			egen `c'_mean = total (`c'_tot), by(appid) m
			replace `c'_mean = `c'_mean / `c'_count / 2
			foreach x in 7d 7d7 {
				gen `c'_absdev_`x' = abs(`c'_`x'_p99_e - `c'_mean)
				gen `c'_sqdev_`x' = (`c'_`x'_p99_e - `c'_mean)^2
			}
			foreach z in absdev sqdev {
				egen `c'_`z'_tot = rowtotal (`c'_`z'_7d `c'_`z'_7d7), m
				egen `c'_`z'_e = total (`c'_`z'_tot) , by(appid) m
				replace `c'_`z'_e =  `c'_`z'_e/`c'_count
			}
			la var `c'_absdev_e "Average absolute deviation from mean: `c'"
			replace `c'_sqdev_e = sqrt(`c'_sqdev_e) 
			la var `c'_sqdev_e "Standard deviation: `c'"
			drop `c'_tot `c'_count `c'_mean `c'_mean
	}
	
*******************************************
*** 13. COHORT AND COHORT INTERACTION TERMS 				
*******************************************

	// a. Cohort dummies
			
			gen coh1=(projid==101)
				la var coh1 "Burayu1"
			gen coh2=(projid==102) 
				la var coh2 "Burayu2"
			gen coh3=(projid==103) 
				la var coh3 "Jittu"
			gen coh4=(projid==104)
				la var coh4 "Redfox"
			gen coh5=(projid==105) 
				la var coh5 "Maa"		
			gen coh6=(projid==106) 
				la var coh6 "Anbesa"		
			gen coh7=(projid==107) 
				la var coh7 "Maa2"		
			gen coh8=(projid==108) 
				la var coh8 "Maa3"
				
			gl cohort "coh1 coh2 coh3 coh4 coh5 coh6 coh7 coh8" 
	// b. Cohort - Gender Dummies
			gen coh1m=(projid==101 & male_b == 1)
				la var coh1m "Burayu1 -  Men"
			gen coh1f=(projid==101 & male_b != 1)
				la var coh1f "Burayu1 -  Women"
			gen coh2m=(projid==102 & male_b == 1) 
				la var coh2m "Burayu2 - Men"
			gen coh2f=(projid==102 & male_b != 1) 
				la var coh2f "Burayu2 - Women"
			gen coh3m=(projid==103 & male_b == 1) 
				la var coh3m "Jittu - Men"
			gen coh3f=(projid==103 & male_b != 1) 
				la var coh3f "Jittu - Women"
			gen coh4m=(projid==104 & male_b == 1)
				la var coh4m "Redfox -  Men"
			gen coh4f=(projid==104 & male_b != 1)
				la var coh4f "Redfox -  Women"
			gen coh5m=(projid==105 & male_b == 1)
				la var coh5m "Maa - Men"		
			gen coh5f=(projid==105 & male_b != 1)
				la var coh5f "Maa - Women"
			gen coh6m=(projid==106 & male_b == 1)
				la var coh6m "Anbesa - Men"		
			gen coh6f=(projid==106 & male_b != 1)
				la var coh6f "Anbesa - Women"
			gen coh7m=(projid==107 & male_b == 1)
				la var coh7m "Maa2 - Men"		
			gen coh7f=(projid==107 & male_b != 1)
				la var coh7f "Maa2 - Women"
			gen coh8m=(projid==108 & male_b == 1)
				la var coh8m "Maa3 - Men"
			gen coh8f=(projid==108 & male_b != 1)
				la var coh8f "Maa3 - Women"					
			
			// globals for cohorts
			
			gl cohortt="t_job t102 t103 t104 t105 t106 t107 t108"
			gl c_ilejob="ilejob1 ilejob102 ilejob103 ilejob104 ilejob105 ilejob106 ilejob107 ilejob108" 
			gl c_tdef1="treatdef1 tdef102_1 tdef103_1 tdef104_1 tdef105_1 tdef106_1 tdef107_1 tdef108_1"
			gl c_tdef2="treatdef2 tdef102_2 tdef103_2 tdef104_2 tdef105_2 tdef106_2 tdef107_2 tdef108_2"
			
			gl cohortt_s "t_job t102 t103 t104 t105 t106"
			gl c_tdef2_s "treatdef2 tdef102_2 tdef103_2 tdef104_2 tdef105_2 tdef106_2"
		
					
		/* Endline round indicators */
		gen EL11M = round == 1
			la var EL11M "Indicator for 11 Month Endline"
		gen EL12M = round == 2
			la var EL12M "Indicator for 12 Month Endline"
		gen EL13M = round == 3
			la var EL13M "Indicator for 13 Month Endline"

*************************************************
*** 14. MISCELLANEOUS OTHER VARIABLE CONSTRUCTION
*************************************************
	
	// a. Outcome Families

			*log using "$ILE/Log/Index_factor_analysis.log", replace
				
			gl material2_fam "cash4weeks_p99_std_e consdur_p99_std_e cons_month_p99_std_e"
			gl health_fam "phqtotal_std_e gadtotal_std_e healthproblems_std_e" 				
			gl educ_fam "techhours_p99_std_e unihours_p99_std_e educ_birr_p99_std_e"

		// Health family construction 
				
			local families "health_fam material2_fam educ_fam" 	
				foreach x of local families {									
				egen ind_`x'_e=rmean($`x') if (found_ei1==1 | found_ei2==1)
					sum ind_`x'_e if wave == 1	& (found_ei1==1 | found_ei2==1)									// averages all non-missing values
					replace ind_`x'_e=(ind_`x'_e-r(mean))/r(sd) if wave == 1 & (found_ei1==1 | found_ei2==1)
					sum ind_`x'_e if wave == 1, d
					gen ind_`x'_p99_e = ind_`x'_e
					replace ind_`x'_p99_e = r(p99) if ind_`x'_p99_e>r(p99) & !missing(ind_`x'_p99_e)
				}
									
			// Label Families
			 
					lab var ind_material2_fam_e "Income family index (z-score)"
					lab var ind_educ_fam_e "Education family measure (z-score)"
					lab var ind_health_fam_e "Health family index (z-score), higher better"

					lab var ind_material2_fam_p99_e "Income family index (z-score, capped at p99)"
					lab var ind_educ_fam_p99_e "Education family measure (z-score, capped at p99)"
					lab var ind_health_fam_p99_e "Health family index (z-score, capped at p99), higher better"

	// b. Other measure construction 
		
		// Indicator for any long-term work in a firm > 10 employees in the past month 
					
				foreach x in $igacateg {
				gen `x'long_pmonth = 1 if `x'_pastmonth_e==1 & treatdef_`x' == 1
				replace `x'long_pmonth = 0 if treatdef_`x' == 0 & `x'_pastmonth_e == 0
				replace `x'long_pmonth = . if treatdef_`x' ==. & `x'_pastmonth_e == .
				lab var `x'long_pmonth "Any long-term work in `x' > 10 employees in the past month" 	
				}
				
				egen work_4indweeks_e = anymatch(*_pastmonth_e), values (1)
				egen temp_w = rowtotal(*_pastmonth_e), m
				replace work_4indweeks_e =. if temp_w ==.
				
				egen long_pmonth_e = anymatch(*long_pmonth), values (1)
				egen temp = rowtotal(treatdef_* *pastmonth_e), m
				replace long_pmonth_e =. if temp==.
				lab var long_pmonth_e "Any long-term work in a firm > 10 employees in the past month"
			
		// Migration indicator
			
				gen migrated_e = 0
				replace migrated_e = . if round == 2 & projid >=102
				replace migrated_e = . if (round == 1 | round == 3) & projid == 101
				replace migrated_e = . if round >=4
				replace mig13 = 1 if mig11 == 1
				replace migrated_e = mig12 if round == 2 & projid == 101 & !missing(mig12)
				replace migrated_e = mig11 if round == 1 & projid >= 102 & !missing(mig11)
				replace migrated_e = mig13 if round == 3 & projid >= 102 & !missing(mig13)
				replace migrated_e = migration_att if migrated_e == 0 & migration_att == 1
				replace migrated_e = 0 if found==1  & !missing(migrated_e)
				la var migrated_e "Had migrated at endline"
				
		// Attrition indicators
			foreach x in died lost other ref prison {
				gen `x'_att_e = 0 if round <= 3
				replace `x'_att_e = `x'12 if round == 2 & projid == 101 & !missing(`x'12)
				replace `x'_att_e = `x'11 if round == 1 & projid >= 102 & !missing(`x'11)
				replace `x'_att_e = `x'13 if round == 3 & projid >= 102 & !missing(`x'13)
			}
			
			
			
			/* Recreate aggressive behavior as increasing*/
	
	// AGRESSIVE BEHAVIOR VARIABLES *F*
		// NEGATIVE
			recode agg_insult_e agg_arguehh_e agg_argueout_e agg_argueviolence_e agg_frustration_e agg_fight_e ///
			agg_threat_e agg_arguepolice_e (1=0) (2=1) (3=2) (4=3), pre(r2_)
		// POSITIVE
			recode agg_anger_e (1=3) (2=2) (3=1) (4=0), pre(r2_)
		
			egen aggression_e= rowtotal (r2_agg*), m
			label var aggression_e "Aggressive behavior 27-0 (0: More Aggressive)"
	
	// ATTITUDES TOWARDS LARGE FIRMS/FARMS (HIGHER VALUE: Lower PREFERENCE FOR LARGE FIRMS/FARMS) *F*
		// NEGATIVE QUESTIONS
			recode firms1_e firms4_e firms6_e (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank2_)
		// POSITIVE QUESTIONS
			recode firms2_e firms3_e firms5_e (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank2_)
		
			egen firmsr_att_e = rowtotal(rank2_firms*), m
			lab var firmsr_att_e "Attitudes towards large firms additive index (0-24 Dont Prefer Large Firms)"
			
	/* Recreate anti foreign firm attitudes */
		// NEGATIVE QUESTIONS
			recode foreignfirms1_e foreignfirms3_e foreignfirms4_e (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank2_)
		// POSITIVE QUESTIONS
			recode foreignfirms2_e foreignfirms5_e foreignfirms6_e (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank2_)
			
			egen foreignr_att_e = rowtotal(rank2_foreignfirms*), m
			lab var foreignr_att_e "Attitudes towards large firms additive index (0-24 Preference for Foreign)"
		
		
	gl employment "hourswork_wk_p99_e nowork_dum_e hourswork_sqdev_e"
	gl income "totalprofit7_av_p99_e consdur_p99_std_e cons_month_p99_e"
	gl physhealth "healthproblems_e disabled_e health_laddnow_e healthchange_5years_e"
	gl menthealth "phqtotal_r_e gadtotal_r_e anxiety_e laddnow_e ladd5years_e aggression_e"
	gl socinte "famsupport_e commsupport_e comminvolved_e trust_e"
	gl fempower "femaleempower_e decision_e empowered_e abusein_e"
	gl ncogskills "locuscontrol_e selfesteem_e patience_e riskaversion_e selfcontrol_e punctual_e"
	gl antifirm "firmsr_att_e foreignr_att_e unions_att_e workrights_per_e"
	
	foreach fam in employment income physhealth menthealth socinte ncogskills fempower antifirm {
		foreach v of global `fam' {
			qui gen Z_`v' = `v' if round <= 3
			qui sum Z_`v' 
			qui replace Z_`v'  = (Z_`v' - r(mean))/r(sd)
			
			if inlist("`v'","nowork_dum_e","hourswork_sqdev_e","disabled_e","phqtotal_r_e","gadtotal_r_e","anxiety_e", "aggression_e") replace Z_`v' = -Z_`v'	
		}
		egen `fam'familyindex_e = rowtotal(Z_*), m
		qui sum `fam'familyindex_e if round<=3
		qui replace `fam'familyindex_e  = (`fam'familyindex_e - r(mean))/r(sd)
		la var `fam'familyindex_e "Family index of `fam' variables"
		pause
		drop Z_*
	}
	
	
*************************************************
*** 15. CREATE ENDLINE AVERAGES AND MAX
*************************************************	

	/* Create maximums for take up measures */
	foreach x in treatdef1 treatdef3 facfarm_e anyfacfarm_m_e anyfacfarm_w anybigfirm_e worked_goodft_sec7_e worked_good_sec7_e reggoodwork_e {
						egen `x'_max = max(`x'), by(appid wave)
						loc lab: var lab `x'
						la var `x'_max `"EndlineMax:`lab'"'	
	}
	/* Recoding months in factory or farm, by hand */
	qui replace anyfacfarm_m_e_max = 13 if (appid == 10112 | appid == 10166 | appid == 10210 | appid == 10217 | ///
											appid == 10219 | appid == 10220 | appid == 10243 | appid == 10248 | ///
											appid == 10261 | appid == 10262 | appid == 10268 | appid == 10302 | ///
											appid == 10308 | appid == 10312 | appid == 10324 | appid == 10344 | ///
											appid == 10355 | appid == 10362 | appid == 10385 | appid == 10396 | ///
											appid == 10398 | appid == 10429 | appid == 10457 | appid == 10463 | ///
											appid == 10468 | appid == 10470 | appid == 10485 | appid == 10526 | ///
											appid == 10531 | appid == 10582 | appid == 10601 | appid == 10632 | ///
											appid == 10634 | appid == 10648 | appid == 10655 | appid == 10684 | ///
											appid == 10697 | appid == 10704 | appid == 10705 | appid == 10706 | ///
											appid == 10759 | appid == 10775 | appid == 11300 | appid == 11319 | ///
											appid == 11337 | appid == 11507 | appid == 11516 | appid == 11527 | ///
											appid == 11528 | appid == 11606 | appid == 11612 | appid == 11632 | ///
											appid == 11733 | appid == 11742 | appid == 11751 | appid == 11753 | ///
											appid == 11763 )
	qui replace anyfacfarm_m_e_max = 5.5 if (appid == 10122)		

	qui replace punctual_e = . if  round==1
	foreach var in famsupport_e commsupport_e comminvolved_e trust_e {
		replace `var' = . if round==3 
	}
	foreach x in hourswork_1w_p99_e facthours_1w_p99_e aghoursoth_1w_p99_e aghourscom_1w_p99_e 						///
						pettybusnhours_1w_p99_e skilledhours_1w_p99_e cashours_1w_p99_e wagelowhours_1w_p99_e 	///
						wagemedhours_1w_p99_e othhours_1w_p99_e long_pmonth_e facfarm_e bigfac_pastmonth_e 		///
						bigfarmwage_pastmonth_e fulltimereg_e workcond_p99_std_e  timeuse_leisure_p99_e 			///
						timeuse_commute_p99_e timeuse_domestic_p99_e migrated_e found found_hh ind_material2_fam_p99_e 	///
						cash4weeks_p99_e totalprofit7_av_p99_e consdur_p99_std_e proddur_p99_std_e cons_month_p99_std_e 			///
						save4weeks_p99_e stat_change1_e stat_change3_e healthproblems_e 	///
						phqtotal_r_e gadtotal_r_e totalcash7_av_p99_e laddnow_e schooltrainnow_e currentschool_e ///
						indperception_e r_enoughchores_e r_enoughtime_e r_enoughmoney_e r_consultlargeexpense_e ///
						r_consultsmallexpense_e r_consultbigdecisions_e r_consultfirst_e r_respect_e 	///
						r_valueopinionhh_e r_valueopinionpersonal_e tech_3m_e uni_3m_e tech_1y_e uni_1y_e ///
						psnphours_1w_e anxiety_e rank_educ_anxiety_e rank_health_anxiety_e rank_othessentials_anxiety_e ///
						rank_other_anxiety_e anyhealthproblem_e disabled_e disabled1_e workcond_p99_e psnphours_1w_p99_e ///
						nowork_dum_e zeroprofit2w_e zerocash4w_e adultfood_security_e 	///
						cash_1w_p99_e hourswork_wk_p99_e facthours_wk_p99_e aghoursoth_wk_p99_e aghourscom_wk_p99_e 						///
						pettybusnhours_wk_p99_e skilledhours_wk_p99_e cashours_wk_p99_e wagelowhours_wk_p99_e 	///
						wagemedhours_wk_p99_e othhours_wk_p99_e health_laddnow_e anyfacfarm_m_e ///
						offer treatmentfirm_1d treatmentfirm_30d anybigfirm_e_max treatdef3_max anyfacfarm_m_e_max ///
						stdyfirmnow stdyfirmnow_lib offer_n accept_n receive_n hourswork_sqdev_e ///
						firmsr_att_e foreignr_att_e unions_att_e workrights_per_e ///
						locuscontrol_e selfesteem_e patience_e riskaversion_e selfcontrol_e punctual_e ///
						femaleempower_e decision_e empowered_e abusein_e ///
						famsupport_e commsupport_e comminvolved_e trust_e cons_month_p99_e  /// 
						healthchange_5years_e ladd5years_e aggression_e ///
						seriousdif_carry20liters_e seriousdif_dayactiv_e seriousdif_walk2km_e seriousdif_workbench_e seriousdif_workout_e ///
						disabled2_e disabled3_e disabled4_e treatdef3 ///
						somedif_carry20liters_e somedif_dayactiv_e somedif_walk2km_e somedif_workbench_e somedif_workout_e {
						egen `x'_av = mean(`x'), by(appid wave)
						loc lab: var lab `x'
						la var `x'_av "Endline Avg.:`lab'"
	}
	gen round_11 = 1 if round_i==1
	gen round_13 = 1 if round_i==3
	egen r_11 = min(round_11), by(appid)
	egen r_13 = min(round_13), by(appid)
	gen twice = r_11==1&r_13==1
	egen max_round = max(round_i), by(appid)
	gen weight = 1
	replace weight = 2 if found_av==1 & twice==1
	egen weight_final = max(weight), by(appid)
	la var weight_final "Weight to test if avg = pool"
	drop weight 
	
	replace found_av = 1 if found_av == .5
	la var found_av "Found for at least 1 of the rounds in wave (i.e., endline average exists)"
	
	
	** CREATE FAMILY OF AVERAGED COMPONENTS **
	
	gl employment "hourswork_wk_p99_e nowork_dum_e hourswork_sqdev_e"
	gl income "totalprofit7_av_p99_e consdur_p99_std_e cons_month_p99_e"
	gl physhealth "healthproblems_e disabled_e health_laddnow_e healthchange_5years_e"
	gl menthealth "phqtotal_r_e gadtotal_r_e anxiety_e laddnow_e ladd5years_e aggression_e"
	gl socinte "famsupport_e commsupport_e comminvolved_e trust_e"
	gl fempower "femaleempower_e decision_e empowered_e abusein_e"
	gl ncogskills "locuscontrol_e selfesteem_e patience_e riskaversion_e selfcontrol_e punctual_e"
	gl antifirm "firmsr_att_e foreignr_att_e unions_att_e workrights_per_e"
	
	foreach fam in employment income physhealth menthealth socinte ncogskills fempower antifirm {
		foreach v of global `fam' {
			qui gen Z_`v' = `v'_av 
			qui sum Z_`v' if round <= 2
			qui replace Z_`v'  = (Z_`v' - r(mean))/r(sd)
			
			if inlist("`v'","nowork_dum_e","hourswork_sqdev_e","disabled_e","phqtotal_r_e","gadtotal_r_e", "anxiety_e", "aggression_e") replace Z_`v' = -Z_`v'	
		}
		egen `fam'familyindex_e_av = rowtotal(Z_*), m
		qui sum `fam'familyindex_e_av if round<=2
		qui replace `fam'familyindex_e_av  = (`fam'familyindex_e_av - r(mean))/r(sd)
		la var `fam'familyindex_e_av "Family index of `fam' variables"
		pause
		drop Z_*
	}
	
	/* AVERAGE PROFITS FROM AVERAGES */
	foreach s in b e_av e {
	// AVERAGE PROFIT EARNED PER HOUR IN THE PAST TWO WEEKS (AVERAGE: PAST 7 DAYS and 7 DAYS BEFORE PAST 7 DAYS)
			gen totalprofit_h_av_`s' = totalprofit7_av_p99_`s' / hourswork_wk_p99_`s'
			label var totalprofit_h_av_`s' "Average earnings per hour over last 2 weeks"
			gen totalprofit_h_av_zero_`s' = totalprofit_h_av_`s'
			replace totalprofit_h_av_zero_`s' = 0 if totalprofit7_av_p99_`s' == 0 | hourswork_wk_p99_`s' == 0
			label var totalprofit_h_av_zero_`s' "Average earnings per hour over last 2 weeks, zero if zero hours"

	/* CAP HOURLY EARNINGS */
	foreach x in totalprofit_h_av totalprofit_h_av_zero { // 
				local lbl: variable label `x'_`s'
				gen `x'_p99_`s' =`x'_`s'		    // 99% cutoff
				qui sum `x'_`s' if round<=2,d
				replace `x'_p99_`s'=r(p99) if `x'_p99_`s'>r(p99) & `x'_p99_`s'!=.
				la var `x'_p99_`s' "P99: `lbl'"
	}
	
	// AVERAGE PROFIT EARNED PER HOUR IN THE PAST MONTH(AVERAGE: WEEKLY AVERAGES OVER PAST MONTH)
	if "`s'" == "e_av" | "`s'" == "e" {
			gen totalprofit_h_mav_`s' = cash_1w_p99_`s' / hourswork_1w_p99_`s'
			label var totalprofit_h_mav_`s' "Average earnings per hour over past month"	
			gen totalprofit_h_mav_zero_`s' = cash_1w_p99_`s' / hourswork_1w_p99_`s'
			replace totalprofit_h_mav_zero_`s' = 0 if cash_1w_p99_`s' == 0 | hourswork_1w_p99_`s' == 0
			label var totalprofit_h_mav_zero_`s' "Average earnings per hour over past month, zero if zero hours"
			
		/* CAP HOURLY EARNINGS */
		foreach x in totalprofit_h_mav_zero totalprofit_h_mav { // 
					local lbl: variable label `x'_`s'
					gen `x'_p99_`s' =`x'_`s'		    // 99% cutoff
					qui sum `x'_`s' if round<=2,d
					replace `x'_p99_`s'=r(p99) if `x'_p99_`s'>r(p99) & `x'_p99_`s'!=.
					la var `x'_p99_`s' "P99: `lbl'"
		
		}
	}
}
	// DUMMY: <5 HOURS PER WEEK IN LAST 2 WEEKS
	
	gen less5hrs_e = (hourswork_wk_p99_e<5) if !missing(hourswork_wk_p99_e)
		la var less5hrs_e "Worked less than 5 hours per week in past two weeks"
		
	gen less5hrs_e_av = (hourswork_wk_p99_e_av<5) if !missing(hourswork_wk_p99_e_av)
		la var less5hrs_e_av "Worked less than 5 hours per week in past two weeks, EL average"
		
	gen less5hrs_mo_e = (hourswork_1w_p99_e<5) if !missing(hourswork_1w_p99_e)
		la var less5hrs_mo_e "Worked less than 5 hours per week in past month"
		
	gen less5hrs_mo_e_av = (hourswork_1w_p99_e_av<5) if !missing(hourswork_1w_p99_e_av)
		la var less5hrs_mo_e_av "Worked less than 5 hours per week in past month, EL average"
		
	/* Experience dummies */
		gen experproxy = exactage_p99_b - educ_p99_b - 6 
			replace experproxy = 0 if experproxy<0
			la var experproxy "Experience proxy: Age MINUS education MINUS 6"
		gen workexper_yr_p99_b = workexper_mo_p99_b/12
			la var workexper_yr_p99_b "Reported years work experience"
		gen workexper2_yr_p99_b = workexper2_mo_p99_b/12
			la var workexper2_yr_p99_b "Reported years work experience (excluding ag and cas)"

		gen newentrant_b =  experproxy <= 2
			la var newentrant_b "New LM entrant: experience proxy <= 2"
		gen neverworked_b = workexper_yr_p99_b <= 2
			la var neverworked_b "Never worked: reported experience <= 2"
		gen neverworked2_b = workexper2_yr_p99_b <= 2
			la var neverworked2_b "Never worked: reported experience (excluding ag and cas) <= 2"

*************************************************
*** 16. ATTRITION SCENARIOS
*************************************************							
							
		gl outcomes_robustness "facfarm_e_av totalprofit7_av_p99_e_av disabled_e_av stat_change1_e_av"

		set seed 12345
		/* Positive job effects */
		foreach v in facfarm_e totalprofit7_av_p99_e disabled_e {
			qui sum `v' if round<=3 & found == 1
			if r(min)==0 & r(max) == 1 {
				gen randsort = runiform() if round<=3 & found != 1
				sort job ngo randsort
				count if !missing(randsort) & job == 1
					local N_job = r(N)
				count if !missing(randsort) & ngo == 1
					local N_ngo = r(N)
				count if !missing(randsort) & pcg == 1
					local N_pcg = r(N)
				sort job ngo randsort
				by job ngo: gen n = _n if !missing(randsort)
				foreach sd in 10 25 50 {
					gen `v'_`sd'sdJ = `v'
					sum `v' if round<=3 & found == 1
						local pcg1s = floor((r(mean)+.`sd'*r(sd))*`N_pcg')
						local job1s = ceil((r(mean)-.`sd'*r(sd))*`N_job')
						local ngo1s = ceil((r(mean)-.`sd'*r(sd))*`N_ngo')
					foreach t in pcg job ngo {
						replace `v'_`sd'sdJ = cond(n<=``t'1s',1,0) if missing(`v'_`sd'sdJ) & `t' == 1 & round<=3
					}
					la var `v'_`sd'sdJ "`v': 0.`sd' sd attrition scenario"
				}
				drop randsort n
			}
			else {
				foreach sd in 10 25 50 {
					gen `v'_`sd'sdJ = `v'
					replace `v'_`sd'sdJ = (r(mean)+.`sd'*r(sd)) if pcg == 1 & round<=3 & missing(`v'_`sd'sdJ)
					replace `v'_`sd'sdJ = (r(mean)-.`sd'*r(sd)) if job == 1 & round<=3 & missing(`v'_`sd'sdJ)
					replace `v'_`sd'sdJ = (r(mean)-.`sd'*r(sd)) if ngo == 1 & round<=3 & missing(`v'_`sd'sdJ)
					la var `v'_`sd'sdJ "`v': 0.`sd' sd attrition scenario"
				}
			}
		}	
		/* Upper bound on wages */
		foreach v in totalprofit7_av_p99_e {
			qui sum `v' if round<=3 & found == 1
			foreach sd in 10 25 50 {
				gen `v'_`sd'sdJ2 = `v'
				replace `v'_`sd'sdJ2 = (r(mean)-.`sd'*r(sd)) if pcg == 1 & round<=3 & missing(`v'_`sd'sdJ2)
				replace `v'_`sd'sdJ2 = (r(mean)+.`sd'*r(sd)) if job == 1 & round<=3 & missing(`v'_`sd'sdJ2)
				replace `v'_`sd'sdJ2 = (r(mean)+.`sd'*r(sd)) if ngo == 1 & round<=3 & missing(`v'_`sd'sdJ2)
				la var `v'_`sd'sdJ2 "`v': 0.`sd' sd upper bound attrition scenario"
			}
		}	
		/* Negative job effects */
		foreach v in stat_change1_e {
			qui sum `v' if round<=3 & found == 1
			if r(min)==0 & r(max) == 1 {
				gen randsort = runiform() if round<=3 & found != 1
				sort job ngo randsort
				count if !missing(randsort) & job == 1
					local N_job = r(N)
				count if !missing(randsort) & ngo == 1
					local N_ngo = r(N)
				count if !missing(randsort) & pcg == 1
					local N_pcg = r(N)
				sort job ngo randsort
				by job ngo: gen n = _n if !missing(randsort)
				foreach sd in 10 25 50 {
					gen `v'_`sd'sdJ = `v'
					sum `v' if round<=3 & found == 1
						local pcg1s = ceil((r(mean)-.`sd'*r(sd))*`N_pcg')
						local job1s = floor((r(mean)+.`sd'*r(sd))*`N_job')
						local ngo1s = floor((r(mean)+.`sd'*r(sd))*`N_ngo')
					foreach t in pcg job ngo {
						replace `v'_`sd'sdJ = cond(n<=``t'1s',1,0) if missing(`v'_`sd'sdJ) & `t' == 1 & round<=3
					}
					la var `v'_`sd'sdJ "`v': 0.`sd' sd attrition scenario"
				}
				drop randsort n
			}
			else {
				foreach sd in 10 25 50 {
					gen `v'_`sd'sdJ = `v'
					replace `v'_`sd'sdJ = (r(mean)-.`sd'*r(sd)) if pcg == 1 & round<=3 & missing(`v'_`sd'sdJ)
					replace `v'_`sd'sdJ = (r(mean)+.`sd'*r(sd)) if job == 1 & round<=3 & missing(`v'_`sd'sdJ)
					replace `v'_`sd'sdJ = (r(mean)+.`sd'*r(sd)) if ngo == 1 & round<=3 & missing(`v'_`sd'sdJ)
					la var `v'_`sd'sdJ "`v': 0.`sd' sd attrition scenario"
				}
			}
		}
		/* Positive grant effects */
		foreach v in totalprofit7_av_p99_e disabled_e stat_change1_e {
			qui sum `v' if round<=3 & found == 1
			if r(min)==0 & r(max) == 1 {
				gen randsort = runiform() if round<=3 & found != 1
				sort job ngo randsort
				count if !missing(randsort) & job == 1
					local N_job = r(N)
				count if !missing(randsort) & ngo == 1
					local N_ngo = r(N)
				count if !missing(randsort) & pcg == 1
					local N_pcg = r(N)
				sort job ngo randsort
				by job ngo: gen n = _n if !missing(randsort)
				foreach sd in 10 25 50 {
					gen `v'_`sd'sdG = `v'
					sum `v' if round<=3 & found == 1
						local pcg1s = floor((r(mean)+.`sd'*r(sd))*`N_pcg')
						local job1s = ceil((r(mean)-.`sd'*r(sd))*`N_job')
						local ngo1s = ceil((r(mean)-.`sd'*r(sd))*`N_ngo')
					foreach t in pcg job ngo {
						replace `v'_`sd'sdG = cond(n<=``t'1s',1,0) if missing(`v'_`sd'sdG) & `t' == 1 & round<=3
					}
					la var `v'_`sd'sdG "`v': 0.`sd' sd attrition scenario"
				}
				drop randsort n
			}
			else {
				foreach sd in 10 25 50 {
					gen `v'_`sd'sdG = `v'
					replace `v'_`sd'sdG = (r(mean)+.`sd'*r(sd)) if pcg == 1 & round<=3 & missing(`v'_`sd'sdG)
					replace `v'_`sd'sdG = (r(mean)-.`sd'*r(sd)) if job == 1 & round<=3 & missing(`v'_`sd'sdG)
					replace `v'_`sd'sdG = (r(mean)-.`sd'*r(sd)) if ngo == 1 & round<=3 & missing(`v'_`sd'sdG)
					la var `v'_`sd'sdG "`v': 0.`sd' sd attrition scenario"
				}
			}
		}	
		
		/* Negative grant effects */
		foreach v in facfarm_e {
			qui sum `v' if round<=3 & found == 1
			if r(min)==0 & r(max) == 1 {
				gen randsort = runiform() if round<=3 & found != 1
				sort job ngo randsort
				count if !missing(randsort) & job == 1
					local N_job = r(N)
				count if !missing(randsort) & ngo == 1
					local N_ngo = r(N)
				count if !missing(randsort) & pcg == 1
					local N_pcg = r(N)
				sort job ngo randsort
				by job ngo: gen n = _n if !missing(randsort)
				foreach sd in 10 25 50 {
					gen `v'_`sd'sdG = `v'
					sum `v' if round<=3 & found == 1
						local pcg1s = floor((r(mean)-.`sd'*r(sd))*`N_pcg')
						local job1s = ceil((r(mean)+.`sd'*r(sd))*`N_job')
						local ngo1s = ceil((r(mean)+.`sd'*r(sd))*`N_ngo')
					foreach t in pcg job ngo {
						replace `v'_`sd'sdG = cond(n<=``t'1s',1,0) if missing(`v'_`sd'sdG) & `t' == 1 & round<=3
					}
					la var `v'_`sd'sdG "`v': 0.`sd' sd attrition scenario"
				}
				drop randsort n
			}
			else {
				foreach sd in 10 25 50 {
					gen `v'_`sd'sdG = `v'
					replace `v'_`sd'sdG = (r(mean)-.`sd'*r(sd)) if pcg == 1 & round<=3 & missing(`v'_`sd'sdG)
					replace `v'_`sd'sdG = (r(mean)+.`sd'*r(sd)) if job == 1 & round<=3 & missing(`v'_`sd'sdG)
					replace `v'_`sd'sdG = (r(mean)+.`sd'*r(sd)) if ngo == 1 & round<=3 & missing(`v'_`sd'sdG)
					la var `v'_`sd'sdG "`v': 0.`sd' sd attrition scenario"
				}
			}
		}	

		
	
	*************************************************
	*** 17. CREATE BASELINE TO ENDLINE DIFFERENCES **
	*************************************************
	
	foreach v in facfarm hourswork_1w_p99 totalprofit7_av_p99 disabled stat_change1 {
		gen `v'_dif = `v'_e - `v'_b
			la var `v'_dif "EL - BL: `:var lab `v'_e'"
		gen `v'_dif_av = `v'_e_av - `v'_b
			la var `v'_dif_av "EL av. - BL: `:var lab `v'_e_av'"
	}
	
	************************************************
	*** 18. Create Family Indices ******************
	************************************************

	** NEW: Average hourly earnings by job			
				
			foreach x in $igacateg {
				*endline hourly wage
				egen `x'_profithour_avg= rowmean(`x'_profithour_e)
				lab var `x'_profithour_avg "Average profit earned per hour: `x'"
				
				*hourly wage
				qui sum `x'_profithour_avg
				gen `x'_profithourwage = r(mean)
				la var `x'_profithourwage "Estimated hourly wage for `x'"
				
				
				*total income from x
				gen `x'_income = `x'hours_e* `x'_profithourwage
				qui sum `x'_income if inrange(round,1,3),d
				qui replace `x'_income = r(p99) if inrange(`x'_income, r(p99),.)
				la var `x'_income "Annual income from `x'"
				
			}
				
			egen income_y = rowtotal(*_income),m
			qui sum income_y if inrange(round,1,3), d
			qui replace income_y = r(p99) if inrange(income_y, r(p99),.)
			la var income_y "Estimated annual income from all activities"
				
	gen treatmentfirm_30d_e=treatmentfirm_30d
	
		foreach phase in b e {
		egen hoursworktot_wk_p99_`phase' = rowtotal(facthours_wk_p99_`phase' aghourscom_wk_p99_`phase' aghoursoth_wk_p99_`phase'  pettybusnhours_wk_p99_`phase' skilledhours_wk_p99_`phase' cashours_wk_p99_`phase' wagelowhours_wk_p99_`phase' wagemedhours_wk_p99_`phase' othhours_wk_p99_`phase'),m 
	}
	gen nonindhours_wk_p99_e = hoursworktot_wk_p99_e - facthours_wk_p99_e - aghourscom_wk_p99_e
	foreach num in 5 15 25 35 {
		gen nonindhours`num'_wk_p99_e = (nonindhours_wk_p99_e>`num') if !missing(hoursworktot_wk_p99_e)
		lab var nonindhours`num'_wk_p99_e "Worked >`num' hours in non-ind employment"
	}
	
		/* Label some variables */
	la var hourswork_1w_p99_e_av "Average weekly work hours"
	la var hourswork_sqdev_e "Standard deviation of work hours"
	la var cash4weeks_p99_e_av "Monthly cash earnings"
	la var totalprofit7_av_p99_e_av "Weekly profits"
	la var totalprofit_sqdev_e "Standard deviation of weekly profits"
	la var totalprofit_h_av_p99_e_av "Hourly profits"

	
	
		# delimit ;	
		gl outcomes_Econ "employmentfamilyindex_e hourswork_wk_p99_e facthours_wk_p99_e aghourscom_wk_p99_e aghoursoth_wk_p99_e  
						pettybusnhours_wk_p99_e skilledhours_wk_p99_e cashours_wk_p99_e wagelowhours_wk_p99_e
						wagemedhours_wk_p99_e othhours_wk_p99_e nowork_dum_e hourswork_absdev_e hourswork_sqdev_e
						long_pmonth_e facfarm_e bigfac_pastmonth_e 
						bigfarmwage_pastmonth_e fulltimereg_e
						incomefamilyindex_e
						totalprofit7_av_p99_e totalprofit_h_av_p99_e totalprofit_absdev_e  totalprofit_sqdev_e cash4weeks_p99_e totalcash_absdev_e totalcash_sqdev_e 
						zeroprofit2w_e zerocash4w_e consdur_p99_std_e cons_month_p99_e proddur_p99_std_e
						healthrisks_e workcond_e migrated_e save4weeks_p99_e
						timeuse_commute_p99_e timeuse_leisure_p99_e timeuse_domestic_p99_e
						schooltrainnow_e currentschool_e tech_3m_e uni_3m_e";
		gl outcomes_HumanCapital "physhealthfamilyindex_e healthproblems_e disabled_e 
						health_laddnow_e health_laddyearago_e health_5years_e healthchange_lastyear_e healthchange_5years_e 
						menthealthfamilyindex_e phqtotal_r_e gadtotal_r_e
						anxiety_e  
						laddnow_e laddyearago_e ladd5years_e stat_change1_e stat_change3_e ";
		gl outcomes_Workplace "activityhome_e healthrisks_e
								airprob_e badsmell_e dust_e smokefire_e smokemachine_e badair_e
								workcond_e comfort_dum_e temperature_dum_e controlhours_dum_e timeoff_dum_e learnskills_dum_e space_dum_e shortbreaks_dum_e boring_dum_e"; 
		
		gl outcomes_new "hourswork_e facthours_e aghourscom_e aghoursoth_e  
						pettybusnhours_e skilledhours_e cashours_e wagelowhours_e
						wagemedhours_e othhours_e
						income_y"; 
		
		gl outcomes_robustness "facfarm totalprofit7_av_p99 disabled stat_change1";
		gl outcomes_IndPerception "indperception_e r_enoughchores_e r_enoughtime_e r_enoughmoney_e 
						r_consultlargeexpense_e r_consultsmallexpense_e r_consultbigdecisions_e
						r_consultfirst_e r_respect_e r_valueopinionhh_e r_valueopinionpersonal_e singlehh_e";
		
	# delimit cr  
	foreach x in $outcomes_Econ $outcomes_HumanCapital $outcomes_Workplace $outcomes_new $outcomes_robustness $outcomes_IndPerception {
						cap {
							egen `x'_av = mean(`x'), by(appid wave)
							loc lab: var lab `x'
							la var `x'_av "Endline Avg.:`lab'"
						}
	}
	
	*****************************************
	saveold "$ILEdata/ILEanalysis.dta", replace 
	*****************************************

// CLOSE LOG FILE
	
	*log close
